(FAMILY t1-stixgebolditalic)
(CODINGSCHEME STIXT1)
(DESIGNSIZE R 10.0)
(DESIGNUNITS R 1000)
(COMMENT DESIGNSIZE (1 em) IS IN POINTS)
(COMMENT OTHER DIMENSIONS ARE MULTIPLES OF DESIGNSIZE/1000)
(BOUNDARYCHAR O 27)
(FONTDIMEN
   (SLANT R 0.292989)
   (SPACE D 250)
   (STRETCH D 125)
   (SHRINK D 83)
   (XHEIGHT D 449)
   (QUAD D 1000)
   (EXTRASPACE D 83)
   )
(LIGTABLE
   (LABEL O 17) (comment guilsinglright)
   (KRN O 230 R -61) (comment Ydieresis)
   (KRN O 335 R -61) (comment Yacute)
   (KRN O 303 R -18) (comment Atilde)
   (KRN O 300 R -18) (comment Agrave)
   (KRN O 302 R -18) (comment Acircumflex)
   (KRN C A R -18)
   (KRN C T R -56)
   (KRN C V R -55)
   (KRN C W R -54)
   (KRN C Y R -61)
   (KRN O 301 R -18) (comment Aacute)
   (KRN O 304 R -18) (comment Adieresis)
   (KRN O 305 R -18) (comment Aring)
   (KRN O 306 R -28) (comment AE)
   (STOP)
   (LABEL O 20) (comment quotedblleft)
   (KRN O 303 R -44) (comment Atilde)
   (KRN O 300 R -44) (comment Agrave)
   (KRN O 302 R -44) (comment Acircumflex)
   (KRN C A R -44)
   (KRN C V R 3)
   (KRN C W R 4)
   (KRN O 301 R -44) (comment Aacute)
   (KRN O 304 R -44) (comment Adieresis)
   (KRN O 305 R -44) (comment Aring)
   (KRN O 306 R -60) (comment AE)
   (STOP)
   (LABEL O 21) (comment quotedblright)
   (KRN O 230 R 4) (comment Ydieresis)
   (KRN O 335 R 4) (comment Yacute)
   (KRN O 303 R -39) (comment Atilde)
   (KRN O 300 R -39) (comment Agrave)
   (KRN O 302 R -39) (comment Acircumflex)
   (KRN C A R -39)
   (KRN C T R 13)
   (KRN C V R 14)
   (KRN C W R 15)
   (KRN C Y R 4)
   (KRN O 301 R -39) (comment Aacute)
   (KRN O 304 R -39) (comment Adieresis)
   (KRN O 305 R -39) (comment Aring)
   (KRN O 306 R -60) (comment AE)
   (STOP)
   (LABEL O 22) (comment quotedblbase)
   (KRN O 230 R -27) (comment Ydieresis)
   (KRN O 335 R -27) (comment Yacute)
   (KRN O 303 R 41) (comment Atilde)
   (KRN C A R 41)
   (KRN C T R -19)
   (KRN C V R -47)
   (KRN C W R -44)
   (KRN C Y R -27)
   (KRN O 300 R 41) (comment Agrave)
   (KRN O 301 R 41) (comment Aacute)
   (KRN O 302 R 41) (comment Acircumflex)
   (KRN O 304 R 41) (comment Adieresis)
   (KRN O 305 R 41) (comment Aring)
   (KRN O 306 R 39) (comment AE)
   (STOP)
   (LABEL O 24) (comment guillemotright)
   (KRN O 230 R -53) (comment Ydieresis)
   (KRN O 335 R -53) (comment Yacute)
   (KRN O 303 R -11) (comment Atilde)
   (KRN O 300 R -11) (comment Agrave)
   (KRN O 302 R -11) (comment Acircumflex)
   (KRN C A R -11)
   (KRN C T R -48)
   (KRN C V R -48)
   (KRN C W R -47)
   (KRN C Y R -53)
   (KRN O 301 R -11) (comment Aacute)
   (KRN O 304 R -11) (comment Adieresis)
   (KRN O 305 R -11) (comment Aring)
   (KRN O 306 R -20) (comment AE)
   (STOP)
   (LABEL O 25) (comment endash)
   (LIG O 55 O 26)
   (STOP)
   (LABEL O 33) (comment ff)
   (LIG C l O 37)
   (LIG C i O 36)
   (STOP)
   (LABEL O 41) (comment exclam)
   (LIG O 140 O 275)
   (STOP)
   (LABEL O 47) (comment quoteright)
   (LIG O 47 O 21)
   (KRN O 270 R -10) (comment ydieresis)
   (KRN O 375 R -10) (comment yacute)
   (KRN O 262 R -16) (comment scaron)
   (KRN O 365 R -31) (comment otilde)
   (KRN O 370 R -31) (comment oslash)
   (KRN O 362 R -31) (comment ograve)
   (KRN O 366 R -31) (comment odieresis)
   (KRN O 364 R -31) (comment ocircumflex)
   (KRN O 363 R -31) (comment oacute)
   (KRN O 303 R -56) (comment Atilde)
   (KRN O 54 R -42) (comment comma)
   (KRN O 56 R -42) (comment period)
   (KRN C A R -56)
   (KRN C d R -34)
   (KRN C o R -31)
   (KRN C r R -12)
   (KRN C s R -16)
   (KRN C t R -10)
   (KRN C v R -10)
   (KRN C w R -10)
   (KRN C y R -10)
   (KRN O 300 R -56) (comment Agrave)
   (KRN O 301 R -56) (comment Aacute)
   (KRN O 302 R -56) (comment Acircumflex)
   (KRN O 304 R -56) (comment Adieresis)
   (KRN O 305 R -56) (comment Aring)
   (KRN O 306 R -76) (comment AE)
   (STOP)
   (LABEL O 54) (comment comma)
   (KRN C 1 R -10)
   (KRN O 47 R -18) (comment quoteright)
   (KRN O 21 R -1) (comment quotedblright)
   (STOP)
   (LABEL O 55) (comment hyphen)
   (LIG O 55 O 25)
   (KRN O 230 R -39) (comment Ydieresis)
   (KRN O 335 R -39) (comment Yacute)
   (KRN O 303 R 6) (comment Atilde)
   (KRN O 300 R 6) (comment Agrave)
   (KRN O 302 R 6) (comment Acircumflex)
   (KRN C A R 6)
   (KRN C T R -34)
   (KRN C V R -37)
   (KRN C W R -34)
   (KRN C Y R -39)
   (KRN O 301 R 6) (comment Aacute)
   (KRN O 304 R 6) (comment Adieresis)
   (KRN O 305 R 6) (comment Aring)
   (KRN O 306 R -3) (comment AE)
   (STOP)
   (LABEL O 56) (comment period)
   (KRN O 47 R -21) (comment quoteright)
   (KRN O 21 R -4) (comment quotedblright)
   (STOP)
   (LABEL O 74) (comment less)
   (LIG O 74 O 23)
   (STOP)
   (LABEL O 76) (comment greater)
   (LIG O 76 O 24)
   (STOP)
   (LABEL O 77) (comment question)
   (LIG O 140 O 276)
   (STOP)
   (LABEL C A)
   (KRN O 270 R -41) (comment ydieresis)
   (KRN O 230 R -100) (comment Ydieresis)
   (KRN O 375 R -41) (comment yacute)
   (KRN O 335 R -100) (comment Yacute)
   (KRN O 365 R -16) (comment otilde)
   (KRN O 325 R -36) (comment Otilde)
   (KRN O 370 R -16) (comment oslash)
   (KRN O 330 R -36) (comment Oslash)
   (KRN O 362 R -16) (comment ograve)
   (KRN O 322 R -36) (comment Ograve)
   (KRN O 364 R -16) (comment ocircumflex)
   (KRN O 324 R -36) (comment Ocircumflex)
   (KRN O 363 R -16) (comment oacute)
   (KRN O 323 R -36) (comment Oacute)
   (KRN O 350 R -17) (comment egrave)
   (KRN O 353 R -17) (comment edieresis)
   (KRN O 352 R -17) (comment ecircumflex)
   (KRN O 351 R -17) (comment eacute)
   (KRN O 343 R -4) (comment atilde)
   (KRN O 345 R -4) (comment aring)
   (KRN O 340 R -4) (comment agrave)
   (KRN O 344 R -4) (comment adieresis)
   (KRN O 342 R -4) (comment acircumflex)
   (KRN O 341 R -4) (comment aacute)
   (KRN O 54 R 13) (comment comma)
   (KRN O 55 R -6) (comment hyphen)
   (KRN O 56 R 18) (comment period)
   (KRN C C R -38)
   (KRN C G R -34)
   (KRN C O R -36)
   (KRN C Q R -36)
   (KRN C T R -55)
   (KRN C U R -65)
   (KRN C V R -105)
   (KRN C W R -105)
   (KRN C Y R -100)
   (KRN C a R -4)
   (KRN C b R -2)
   (KRN C c R -14)
   (KRN C d R -3)
   (KRN C e R -17)
   (KRN C g R -16)
   (KRN C o R -16)
   (KRN C q R -12)
   (KRN C t R -3)
   (KRN C u R -14)
   (KRN C v R -34)
   (KRN C w R -37)
   (KRN C y R -41)
   (KRN O 23 R -34) (comment guillemotleft)
   (KRN O 307 R -38) (comment Ccedilla)
   (KRN O 326 R -36) (comment Odieresis)
   (KRN O 331 R -65) (comment Ugrave)
   (KRN O 332 R -65) (comment Uacute)
   (KRN O 333 R -65) (comment Ucircumflex)
   (KRN O 334 R -65) (comment Udieresis)
   (KRN O 347 R -18) (comment ccedilla)
   (KRN O 366 R -16) (comment odieresis)
   (KRN O 371 R -14) (comment ugrave)
   (KRN O 372 R -14) (comment uacute)
   (KRN O 373 R -14) (comment ucircumflex)
   (KRN O 374 R -14) (comment udieresis)
   (KRN O 47 R -66) (comment quoteright)
   (KRN O 21 R -49) (comment quotedblright)
   (KRN O 16 R -41) (comment guilsinglleft)
   (STOP)
   (LABEL C B)
   (KRN O 230 R -38) (comment Ydieresis)
   (KRN O 335 R -38) (comment Yacute)
   (KRN O 325 R -7) (comment Otilde)
   (KRN O 300 R -26) (comment Agrave)
   (KRN C A R -26)
   (KRN C O R -7)
   (KRN C V R -36)
   (KRN C W R -32)
   (KRN C Y R -38)
   (KRN O 301 R -26) (comment Aacute)
   (KRN O 302 R -26) (comment Acircumflex)
   (KRN O 303 R -26) (comment Atilde)
   (KRN O 304 R -26) (comment Adieresis)
   (KRN O 305 R -26) (comment Aring)
   (KRN O 306 R -27) (comment AE)
   (KRN O 322 R -7) (comment Ograve)
   (KRN O 323 R -7) (comment Oacute)
   (KRN O 324 R -7) (comment Ocircumflex)
   (KRN O 326 R -7) (comment Odieresis)
   (KRN O 330 R -7) (comment Oslash)
   (KRN O 327 R -2) (comment OE)
   (STOP)
   (LABEL C C)
   (KRN O 325 R -7) (comment Otilde)
   (KRN O 330 R -7) (comment Oslash)
   (KRN O 324 R -7) (comment Ocircumflex)
   (KRN O 303 R -22) (comment Atilde)
   (KRN O 302 R -22) (comment Acircumflex)
   (KRN C A R -22)
   (KRN C H R -12)
   (KRN C K R -13)
   (KRN C O R -7)
   (KRN O 300 R -22) (comment Agrave)
   (KRN O 301 R -22) (comment Aacute)
   (KRN O 304 R -22) (comment Adieresis)
   (KRN O 305 R -22) (comment Aring)
   (KRN O 306 R -23) (comment AE)
   (KRN O 322 R -7) (comment Ograve)
   (KRN O 323 R -7) (comment Oacute)
   (KRN O 326 R -7) (comment Odieresis)
   (STOP)
   (LABEL C D)
   (KRN O 230 R -35) (comment Ydieresis)
   (KRN O 335 R -35) (comment Yacute)
   (KRN C A R -29)
   (KRN C J R -50)
   (KRN C T R -21)
   (KRN C V R -34)
   (KRN C W R -33)
   (KRN C X R -38)
   (KRN C Y R -35)
   (KRN O 300 R -29) (comment Agrave)
   (KRN O 301 R -29) (comment Aacute)
   (KRN O 302 R -29) (comment Acircumflex)
   (KRN O 303 R -29) (comment Atilde)
   (KRN O 304 R -29) (comment Adieresis)
   (KRN O 305 R -29) (comment Aring)
   (STOP)
   (LABEL C F)
   (KRN O 371 R -27) (comment ugrave)
   (KRN O 374 R -27) (comment udieresis)
   (KRN O 373 R -27) (comment ucircumflex)
   (KRN O 372 R -27) (comment uacute)
   (KRN O 365 R -50) (comment otilde)
   (KRN O 325 R -34) (comment Otilde)
   (KRN O 330 R -34) (comment Oslash)
   (KRN O 362 R -50) (comment ograve)
   (KRN O 364 R -50) (comment ocircumflex)
   (KRN O 324 R -34) (comment Ocircumflex)
   (KRN O 354 R -22) (comment igrave)
   (KRN O 357 R -22) (comment idieresis)
   (KRN O 356 R -22) (comment icircumflex)
   (KRN O 355 R -22) (comment iacute)
   (KRN O 350 R -58) (comment egrave)
   (KRN O 353 R -58) (comment edieresis)
   (KRN O 352 R -58) (comment ecircumflex)
   (KRN O 340 R -47) (comment agrave)
   (KRN O 54 R -59) (comment comma)
   (KRN O 55 R -28) (comment hyphen)
   (KRN O 56 R -61) (comment period)
   (KRN C A R -61)
   (KRN C J R -66)
   (KRN C O R -34)
   (KRN C a R -47)
   (KRN C e R -58)
   (KRN C i R -22)
   (KRN C j R -26)
   (KRN C o R -50)
   (KRN C r R -24)
   (KRN C u R -27)
   (KRN O 300 R -61) (comment Agrave)
   (KRN O 301 R -61) (comment Aacute)
   (KRN O 302 R -61) (comment Acircumflex)
   (KRN O 303 R -61) (comment Atilde)
   (KRN O 304 R -61) (comment Adieresis)
   (KRN O 305 R -61) (comment Aring)
   (KRN O 322 R -34) (comment Ograve)
   (KRN O 323 R -34) (comment Oacute)
   (KRN O 326 R -34) (comment Odieresis)
   (KRN O 341 R -47) (comment aacute)
   (KRN O 342 R -47) (comment acircumflex)
   (KRN O 343 R -45) (comment atilde)
   (KRN O 344 R -42) (comment adieresis)
   (KRN O 345 R -47) (comment aring)
   (KRN O 346 R -54) (comment ae)
   (KRN O 351 R -58) (comment eacute)
   (KRN O 363 R -50) (comment oacute)
   (KRN O 366 R -36) (comment odieresis)
   (KRN O 370 R -50) (comment oslash)
   (KRN O 367 R -58) (comment oe)
   (STOP)
   (LABEL C G)
   (KRN O 230 R -22) (comment Ydieresis)
   (KRN O 335 R -22) (comment Yacute)
   (KRN C A R -10)
   (KRN C T R -22)
   (KRN C V R -20)
   (KRN C W R -19)
   (KRN C Y R -22)
   (KRN O 300 R -10) (comment Agrave)
   (KRN O 301 R -10) (comment Aacute)
   (KRN O 302 R -10) (comment Acircumflex)
   (KRN O 303 R -10) (comment Atilde)
   (KRN O 304 R -10) (comment Adieresis)
   (KRN O 305 R -10) (comment Aring)
   (KRN O 306 R -12) (comment AE)
   (STOP)
   (LABEL C J)
   (KRN O 303 R -30) (comment Atilde)
   (KRN O 300 R -30) (comment Agrave)
   (KRN O 302 R -30) (comment Acircumflex)
   (KRN O 301 R -30) (comment Aacute)
   (KRN C A R -30)
   (KRN O 304 R -30) (comment Adieresis)
   (KRN O 305 R -30) (comment Aring)
   (KRN O 306 R -32) (comment AE)
   (STOP)
   (LABEL C K)
   (KRN O 270 R -49) (comment ydieresis)
   (KRN O 375 R -49) (comment yacute)
   (KRN O 371 R -7) (comment ugrave)
   (KRN O 373 R -7) (comment ucircumflex)
   (KRN O 372 R -7) (comment uacute)
   (KRN O 222 R -1) (comment Scaron)
   (KRN O 365 R -8) (comment otilde)
   (KRN O 325 R -26) (comment Otilde)
   (KRN O 370 R -8) (comment oslash)
   (KRN O 330 R -26) (comment Oslash)
   (KRN O 362 R -8) (comment ograve)
   (KRN O 322 R -26) (comment Ograve)
   (KRN O 364 R -8) (comment ocircumflex)
   (KRN O 324 R -26) (comment Ocircumflex)
   (KRN O 350 R -10) (comment egrave)
   (KRN O 353 R -10) (comment edieresis)
   (KRN O 352 R -10) (comment ecircumflex)
   (KRN O 351 R -10) (comment eacute)
   (KRN O 307 R -27) (comment Ccedilla)
   (KRN O 343 R 4) (comment atilde)
   (KRN O 340 R 4) (comment agrave)
   (KRN O 342 R 4) (comment acircumflex)
   (KRN O 341 R 4) (comment aacute)
   (KRN O 55 R -9) (comment hyphen)
   (KRN C C R -27)
   (KRN C G R -23)
   (KRN C O R -26)
   (KRN C S R -1)
   (KRN C a R 4)
   (KRN C e R -10)
   (KRN C o R -8)
   (KRN C u R -7)
   (KRN C y R -49)
   (KRN O 323 R -26) (comment Oacute)
   (KRN O 326 R -26) (comment Odieresis)
   (KRN O 344 R 4) (comment adieresis)
   (KRN O 345 R 4) (comment aring)
   (KRN O 346 R -2) (comment ae)
   (KRN O 363 R -8) (comment oacute)
   (KRN O 366 R -8) (comment odieresis)
   (KRN O 374 R -7) (comment udieresis)
   (KRN O 327 R -24) (comment OE)
   (STOP)
   (LABEL C L)
   (KRN O 270 R -6) (comment ydieresis)
   (KRN O 230 R -32) (comment Ydieresis)
   (KRN O 375 R -6) (comment yacute)
   (KRN O 335 R -32) (comment Yacute)
   (KRN O 371 R 21) (comment ugrave)
   (KRN O 331 R -13) (comment Ugrave)
   (KRN O 373 R 21) (comment ucircumflex)
   (KRN O 333 R -13) (comment Ucircumflex)
   (KRN O 372 R 21) (comment uacute)
   (KRN O 332 R -13) (comment Uacute)
   (KRN O 330 R 4) (comment Oslash)
   (KRN O 307 R 1) (comment Ccedilla)
   (KRN O 303 R 31) (comment Atilde)
   (KRN O 300 R 31) (comment Agrave)
   (KRN O 302 R 31) (comment Acircumflex)
   (KRN O 55 R 66) (comment hyphen)
   (KRN C A R 31)
   (KRN C C R 1)
   (KRN C G R 6)
   (KRN C O R 4)
   (KRN C T R -23)
   (KRN C U R -13)
   (KRN C V R -47)
   (KRN C W R -42)
   (KRN C Y R -32)
   (KRN C u R 21)
   (KRN C y R -6)
   (KRN O 301 R 31) (comment Aacute)
   (KRN O 304 R 31) (comment Adieresis)
   (KRN O 305 R 31) (comment Aring)
   (KRN O 306 R 29) (comment AE)
   (KRN O 322 R 4) (comment Ograve)
   (KRN O 323 R 4) (comment Oacute)
   (KRN O 324 R 4) (comment Ocircumflex)
   (KRN O 325 R 4) (comment Otilde)
   (KRN O 326 R 4) (comment Odieresis)
   (KRN O 334 R -13) (comment Udieresis)
   (KRN O 374 R 18) (comment udieresis)
   (KRN O 47 R -49) (comment quoteright)
   (KRN O 21 R -32) (comment quotedblright)
   (STOP)
   (LABEL C N)
   (KRN O 371 R -15) (comment ugrave)
   (KRN O 373 R -15) (comment ucircumflex)
   (KRN O 372 R -15) (comment uacute)
   (KRN O 365 R -11) (comment otilde)
   (KRN O 325 R -11) (comment Otilde)
   (KRN O 330 R -11) (comment Oslash)
   (KRN O 362 R -11) (comment ograve)
   (KRN O 322 R -11) (comment Ograve)
   (KRN O 364 R -11) (comment ocircumflex)
   (KRN O 324 R -11) (comment Ocircumflex)
   (KRN O 350 R -18) (comment egrave)
   (KRN O 353 R -18) (comment edieresis)
   (KRN O 352 R -18) (comment ecircumflex)
   (KRN O 343 R -8) (comment atilde)
   (KRN O 303 R -29) (comment Atilde)
   (KRN O 340 R -8) (comment agrave)
   (KRN O 300 R -29) (comment Agrave)
   (KRN O 342 R -8) (comment acircumflex)
   (KRN O 302 R -29) (comment Acircumflex)
   (KRN O 54 R -4) (comment comma)
   (KRN O 56 R -8) (comment period)
   (KRN C A R -29)
   (KRN C C R -10)
   (KRN C G R -6)
   (KRN C O R -11)
   (KRN C a R -8)
   (KRN C e R -18)
   (KRN C o R -11)
   (KRN C u R -15)
   (KRN O 301 R -29) (comment Aacute)
   (KRN O 304 R -29) (comment Adieresis)
   (KRN O 305 R -29) (comment Aring)
   (KRN O 306 R -30) (comment AE)
   (KRN O 307 R -10) (comment Ccedilla)
   (KRN O 323 R -11) (comment Oacute)
   (KRN O 326 R -11) (comment Odieresis)
   (KRN O 341 R -12) (comment aacute)
   (KRN O 344 R -12) (comment adieresis)
   (KRN O 345 R -12) (comment aring)
   (KRN O 346 R -14) (comment ae)
   (KRN O 351 R -18) (comment eacute)
   (KRN O 363 R -15) (comment oacute)
   (KRN O 366 R -15) (comment odieresis)
   (KRN O 370 R -15) (comment oslash)
   (KRN O 374 R -15) (comment udieresis)
   (STOP)
   (LABEL C O)
   (KRN O 230 R -36) (comment Ydieresis)
   (KRN O 335 R -36) (comment Yacute)
   (KRN O 303 R -30) (comment Atilde)
   (KRN O 300 R -30) (comment Agrave)
   (KRN O 302 R -30) (comment Acircumflex)
   (KRN C A R -30)
   (KRN C T R -15)
   (KRN C V R -31)
   (KRN C W R -30)
   (KRN C X R -35)
   (KRN C Y R -36)
   (KRN O 301 R -30) (comment Aacute)
   (KRN O 304 R -30) (comment Adieresis)
   (KRN O 305 R -30) (comment Aring)
   (KRN O 306 R -40) (comment AE)
   (STOP)
   (LABEL C P)
   (KRN O 365 R -36) (comment otilde)
   (KRN O 362 R -36) (comment ograve)
   (KRN O 364 R -36) (comment ocircumflex)
   (KRN O 350 R -44) (comment egrave)
   (KRN O 353 R -44) (comment edieresis)
   (KRN O 352 R -44) (comment ecircumflex)
   (KRN O 343 R -37) (comment atilde)
   (KRN O 303 R -53) (comment Atilde)
   (KRN O 300 R -53) (comment Agrave)
   (KRN O 342 R -37) (comment acircumflex)
   (KRN O 302 R -53) (comment Acircumflex)
   (KRN O 54 R -70) (comment comma)
   (KRN O 55 R -32) (comment hyphen)
   (KRN O 56 R -70) (comment period)
   (KRN C A R -53)
   (KRN C J R -70)
   (KRN C a R -37)
   (KRN C e R -44)
   (KRN C o R -36)
   (KRN O 301 R -53) (comment Aacute)
   (KRN O 304 R -53) (comment Adieresis)
   (KRN O 305 R -53) (comment Aring)
   (KRN O 306 R -69) (comment AE)
   (KRN O 340 R -36) (comment agrave)
   (KRN O 341 R -36) (comment aacute)
   (KRN O 344 R -34) (comment adieresis)
   (KRN O 345 R -36) (comment aring)
   (KRN O 346 R -45) (comment ae)
   (KRN O 351 R -44) (comment eacute)
   (KRN O 363 R -36) (comment oacute)
   (KRN O 366 R -28) (comment odieresis)
   (KRN O 370 R -36) (comment oslash)
   (KRN O 367 R -42) (comment oe)
   (STOP)
   (LABEL C R)
   (KRN O 270 R -10) (comment ydieresis)
   (KRN O 230 R -30) (comment Ydieresis)
   (KRN O 375 R -10) (comment yacute)
   (KRN O 335 R -30) (comment Yacute)
   (KRN O 371 R -10) (comment ugrave)
   (KRN O 331 R -22) (comment Ugrave)
   (KRN O 373 R -10) (comment ucircumflex)
   (KRN O 333 R -22) (comment Ucircumflex)
   (KRN O 332 R -22) (comment Uacute)
   (KRN O 365 R -12) (comment otilde)
   (KRN O 325 R -15) (comment Otilde)
   (KRN O 370 R -12) (comment oslash)
   (KRN O 330 R -15) (comment Oslash)
   (KRN O 362 R -12) (comment ograve)
   (KRN O 322 R -15) (comment Ograve)
   (KRN O 364 R -12) (comment ocircumflex)
   (KRN O 324 R -15) (comment Ocircumflex)
   (KRN O 350 R -14) (comment egrave)
   (KRN O 353 R -14) (comment edieresis)
   (KRN O 352 R -14) (comment ecircumflex)
   (KRN O 343 R -1) (comment atilde)
   (KRN O 340 R -1) (comment agrave)
   (KRN O 342 R -1) (comment acircumflex)
   (KRN O 55 R -12) (comment hyphen)
   (KRN C C R -14)
   (KRN C G R -10)
   (KRN C O R -15)
   (KRN C T R -18)
   (KRN C U R -22)
   (KRN C V R -36)
   (KRN C W R -35)
   (KRN C Y R -30)
   (KRN C a R -1)
   (KRN C e R -14)
   (KRN C o R -12)
   (KRN C u R -10)
   (KRN C y R -10)
   (KRN O 307 R -14) (comment Ccedilla)
   (KRN O 323 R -15) (comment Oacute)
   (KRN O 326 R -15) (comment Odieresis)
   (KRN O 334 R -22) (comment Udieresis)
   (KRN O 341 R -1) (comment aacute)
   (KRN O 344 R -1) (comment adieresis)
   (KRN O 345 R -1) (comment aring)
   (KRN O 346 R -6) (comment ae)
   (KRN O 351 R -14) (comment eacute)
   (KRN O 363 R -12) (comment oacute)
   (KRN O 366 R -12) (comment odieresis)
   (KRN O 372 R -10) (comment uacute)
   (KRN O 374 R -10) (comment udieresis)
   (KRN O 327 R -14) (comment OE)
   (KRN O 367 R -17) (comment oe)
   (STOP)
   (LABEL C S)
   (KRN O 230 R -18) (comment Ydieresis)
   (KRN O 335 R -18) (comment Yacute)
   (KRN O 303 R -11) (comment Atilde)
   (KRN O 300 R -11) (comment Agrave)
   (KRN O 302 R -11) (comment Acircumflex)
   (KRN C A R -11)
   (KRN C T R -24)
   (KRN C V R -15)
   (KRN C W R -14)
   (KRN C Y R -18)
   (KRN C t R 5)
   (KRN O 301 R -11) (comment Aacute)
   (KRN O 304 R -11) (comment Adieresis)
   (KRN O 305 R -11) (comment Aring)
   (KRN O 306 R -13) (comment AE)
   (STOP)
   (LABEL C T)
   (KRN O 270 R -65) (comment ydieresis)
   (KRN O 230 R 14) (comment Ydieresis)
   (KRN O 375 R -65) (comment yacute)
   (KRN O 335 R 14) (comment Yacute)
   (KRN O 371 R -61) (comment ugrave)
   (KRN O 374 R -61) (comment udieresis)
   (KRN O 373 R -61) (comment ucircumflex)
   (KRN O 372 R -61) (comment uacute)
   (KRN O 262 R -57) (comment scaron)
   (KRN O 222 R -12) (comment Scaron)
   (KRN O 365 R -58) (comment otilde)
   (KRN O 354 R -2) (comment igrave)
   (KRN O 357 R -2) (comment idieresis)
   (KRN O 356 R -2) (comment icircumflex)
   (KRN O 355 R -2) (comment iacute)
   (KRN O 350 R -61) (comment egrave)
   (KRN O 353 R -61) (comment edieresis)
   (KRN O 352 R -61) (comment ecircumflex)
   (KRN O 351 R -61) (comment eacute)
   (KRN O 347 R -58) (comment ccedilla)
   (KRN O 307 R -12) (comment Ccedilla)
   (KRN O 345 R -56) (comment aring)
   (KRN O 54 R -46) (comment comma)
   (KRN O 55 R -43) (comment hyphen)
   (KRN O 56 R -47) (comment period)
   (KRN O 72 R -35) (comment colon)
   (KRN O 73 R -37) (comment semicolon)
   (KRN C A R -40)
   (KRN C C R -12)
   (KRN C G R -8)
   (KRN C J R -48)
   (KRN C O R -18)
   (KRN C S R -12)
   (KRN C V R 16)
   (KRN C W R 18)
   (KRN C Y R 14)
   (KRN C a R -56)
   (KRN C c R -58)
   (KRN C e R -61)
   (KRN C g R -63)
   (KRN C i R -2)
   (KRN C j R -6)
   (KRN C o R -58)
   (KRN C r R -56)
   (KRN C s R -57)
   (KRN C u R -61)
   (KRN C v R -66)
   (KRN C w R -66)
   (KRN C y R -65)
   (KRN O 23 R -69) (comment guillemotleft)
   (KRN O 300 R -40) (comment Agrave)
   (KRN O 301 R -40) (comment Aacute)
   (KRN O 302 R -40) (comment Acircumflex)
   (KRN O 303 R -40) (comment Atilde)
   (KRN O 304 R -40) (comment Adieresis)
   (KRN O 305 R -40) (comment Aring)
   (KRN O 306 R -41) (comment AE)
   (KRN O 322 R -18) (comment Ograve)
   (KRN O 323 R -18) (comment Oacute)
   (KRN O 324 R -18) (comment Ocircumflex)
   (KRN O 325 R -18) (comment Otilde)
   (KRN O 326 R -18) (comment Odieresis)
   (KRN O 330 R -18) (comment Oslash)
   (KRN O 340 R -42) (comment agrave)
   (KRN O 341 R -50) (comment aacute)
   (KRN O 342 R -34) (comment acircumflex)
   (KRN O 343 R -26) (comment atilde)
   (KRN O 344 R -23) (comment adieresis)
   (KRN O 346 R -62) (comment ae)
   (KRN O 362 R -38) (comment ograve)
   (KRN O 363 R -45) (comment oacute)
   (KRN O 364 R -28) (comment ocircumflex)
   (KRN O 366 R -18) (comment odieresis)
   (KRN O 370 R -58) (comment oslash)
   (KRN O 327 R -15) (comment OE)
   (KRN O 16 R -77) (comment guilsinglleft)
   (STOP)
   (LABEL C U)
   (KRN O 361 R -22) (comment ntilde)
   (KRN O 300 R -41) (comment Agrave)
   (KRN O 54 R -18) (comment comma)
   (KRN O 56 R -17) (comment period)
   (KRN C A R -41)
   (KRN C m R -19)
   (KRN C n R -22)
   (KRN C p R -16)
   (KRN C r R -17)
   (KRN O 301 R -41) (comment Aacute)
   (KRN O 302 R -41) (comment Acircumflex)
   (KRN O 303 R -41) (comment Atilde)
   (KRN O 304 R -41) (comment Adieresis)
   (KRN O 305 R -41) (comment Aring)
   (KRN O 306 R -51) (comment AE)
   (STOP)
   (LABEL C V)
   (KRN O 270 R -28) (comment ydieresis)
   (KRN O 375 R -28) (comment yacute)
   (KRN O 371 R -34) (comment ugrave)
   (KRN O 374 R -34) (comment udieresis)
   (KRN O 373 R -34) (comment ucircumflex)
   (KRN O 372 R -34) (comment uacute)
   (KRN O 222 R -22) (comment Scaron)
   (KRN O 354 R -10) (comment igrave)
   (KRN O 357 R -10) (comment idieresis)
   (KRN O 356 R -10) (comment icircumflex)
   (KRN O 355 R -10) (comment iacute)
   (KRN O 353 R -58) (comment edieresis)
   (KRN O 352 R -58) (comment ecircumflex)
   (KRN O 307 R -34) (comment Ccedilla)
   (KRN O 54 R -58) (comment comma)
   (KRN O 55 R -35) (comment hyphen)
   (KRN O 56 R -58) (comment period)
   (KRN O 72 R -32) (comment colon)
   (KRN O 73 R -28) (comment semicolon)
   (KRN C A R -65)
   (KRN C C R -34)
   (KRN C G R -30)
   (KRN C O R -36)
   (KRN C S R -22)
   (KRN C T R 8)
   (KRN C a R -48)
   (KRN C e R -58)
   (KRN C g R -54)
   (KRN C i R -10)
   (KRN C o R -50)
   (KRN C r R -30)
   (KRN C u R -34)
   (KRN C y R -28)
   (KRN O 23 R -61) (comment guillemotleft)
   (KRN O 300 R -65) (comment Agrave)
   (KRN O 301 R -65) (comment Aacute)
   (KRN O 302 R -65) (comment Acircumflex)
   (KRN O 303 R -65) (comment Atilde)
   (KRN O 304 R -65) (comment Adieresis)
   (KRN O 305 R -65) (comment Aring)
   (KRN O 306 R -71) (comment AE)
   (KRN O 322 R -36) (comment Ograve)
   (KRN O 323 R -36) (comment Oacute)
   (KRN O 324 R -36) (comment Ocircumflex)
   (KRN O 325 R -36) (comment Otilde)
   (KRN O 326 R -36) (comment Odieresis)
   (KRN O 330 R -36) (comment Oslash)
   (KRN O 340 R -38) (comment agrave)
   (KRN O 341 R -48) (comment aacute)
   (KRN O 342 R -48) (comment acircumflex)
   (KRN O 343 R -42) (comment atilde)
   (KRN O 344 R -31) (comment adieresis)
   (KRN O 345 R -41) (comment aring)
   (KRN O 346 R -54) (comment ae)
   (KRN O 350 R -27) (comment egrave)
   (KRN O 351 R -58) (comment eacute)
   (KRN O 362 R -34) (comment ograve)
   (KRN O 363 R -50) (comment oacute)
   (KRN O 364 R -50) (comment ocircumflex)
   (KRN O 365 R -38) (comment otilde)
   (KRN O 366 R -26) (comment odieresis)
   (KRN O 370 R -50) (comment oslash)
   (KRN O 16 R -69) (comment guilsinglleft)
   (STOP)
   (LABEL C W)
   (KRN O 270 R -21) (comment ydieresis)
   (KRN O 375 R -21) (comment yacute)
   (KRN O 371 R -26) (comment ugrave)
   (KRN O 374 R -26) (comment udieresis)
   (KRN O 373 R -26) (comment ucircumflex)
   (KRN O 372 R -26) (comment uacute)
   (KRN O 222 R -21) (comment Scaron)
   (KRN O 354 R -8) (comment igrave)
   (KRN O 357 R -8) (comment idieresis)
   (KRN O 356 R -8) (comment icircumflex)
   (KRN O 355 R -8) (comment iacute)
   (KRN O 353 R -39) (comment edieresis)
   (KRN O 352 R -39) (comment ecircumflex)
   (KRN O 307 R -22) (comment Ccedilla)
   (KRN O 54 R -33) (comment comma)
   (KRN O 55 R -18) (comment hyphen)
   (KRN O 56 R -34) (comment period)
   (KRN O 72 R -13) (comment colon)
   (KRN O 73 R -13) (comment semicolon)
   (KRN C A R -49)
   (KRN C C R -22)
   (KRN C G R -17)
   (KRN C O R -23)
   (KRN C S R -21)
   (KRN C T R 9)
   (KRN C a R -30)
   (KRN C e R -39)
   (KRN C g R -40)
   (KRN C i R -8)
   (KRN C o R -32)
   (KRN C r R -23)
   (KRN C u R -26)
   (KRN C y R -21)
   (KRN O 23 R -42) (comment guillemotleft)
   (KRN O 300 R -49) (comment Agrave)
   (KRN O 301 R -49) (comment Aacute)
   (KRN O 302 R -49) (comment Acircumflex)
   (KRN O 303 R -49) (comment Atilde)
   (KRN O 304 R -49) (comment Adieresis)
   (KRN O 305 R -49) (comment Aring)
   (KRN O 306 R -60) (comment AE)
   (KRN O 322 R -23) (comment Ograve)
   (KRN O 323 R -23) (comment Oacute)
   (KRN O 324 R -23) (comment Ocircumflex)
   (KRN O 325 R -23) (comment Otilde)
   (KRN O 326 R -23) (comment Odieresis)
   (KRN O 330 R -23) (comment Oslash)
   (KRN O 340 R -30) (comment agrave)
   (KRN O 341 R -30) (comment aacute)
   (KRN O 342 R -30) (comment acircumflex)
   (KRN O 343 R -30) (comment atilde)
   (KRN O 344 R -30) (comment adieresis)
   (KRN O 345 R -30) (comment aring)
   (KRN O 346 R -36) (comment ae)
   (KRN O 350 R -26) (comment egrave)
   (KRN O 351 R -39) (comment eacute)
   (KRN O 362 R -32) (comment ograve)
   (KRN O 363 R -32) (comment oacute)
   (KRN O 364 R -32) (comment ocircumflex)
   (KRN O 365 R -32) (comment otilde)
   (KRN O 366 R -29) (comment odieresis)
   (KRN O 370 R -32) (comment oslash)
   (KRN O 16 R -50) (comment guilsinglleft)
   (STOP)
   (LABEL C X)
   (KRN O 270 R -57) (comment ydieresis)
   (KRN O 375 R -57) (comment yacute)
   (KRN O 371 R -17) (comment ugrave)
   (KRN O 374 R -17) (comment udieresis)
   (KRN O 373 R -17) (comment ucircumflex)
   (KRN O 372 R -17) (comment uacute)
   (KRN O 365 R -18) (comment otilde)
   (KRN O 325 R -32) (comment Otilde)
   (KRN O 370 R -18) (comment oslash)
   (KRN O 330 R -32) (comment Oslash)
   (KRN O 362 R -18) (comment ograve)
   (KRN O 322 R -32) (comment Ograve)
   (KRN O 366 R -18) (comment odieresis)
   (KRN O 364 R -18) (comment ocircumflex)
   (KRN O 324 R -32) (comment Ocircumflex)
   (KRN O 363 R -18) (comment oacute)
   (KRN O 323 R -32) (comment Oacute)
   (KRN O 350 R -20) (comment egrave)
   (KRN O 353 R -20) (comment edieresis)
   (KRN O 352 R -20) (comment ecircumflex)
   (KRN O 351 R -20) (comment eacute)
   (KRN O 307 R -30) (comment Ccedilla)
   (KRN O 343 R -7) (comment atilde)
   (KRN O 345 R -7) (comment aring)
   (KRN O 340 R -7) (comment agrave)
   (KRN O 344 R -7) (comment adieresis)
   (KRN O 342 R -7) (comment acircumflex)
   (KRN O 341 R -7) (comment aacute)
   (KRN O 55 R -23) (comment hyphen)
   (KRN C C R -30)
   (KRN C O R -32)
   (KRN C Q R -32)
   (KRN C a R -7)
   (KRN C e R -20)
   (KRN C o R -18)
   (KRN C u R -17)
   (KRN C y R -57)
   (KRN O 326 R -32) (comment Odieresis)
   (STOP)
   (LABEL C Y)
   (KRN O 371 R -42) (comment ugrave)
   (KRN O 374 R -42) (comment udieresis)
   (KRN O 373 R -42) (comment ucircumflex)
   (KRN O 372 R -42) (comment uacute)
   (KRN O 222 R -22) (comment Scaron)
   (KRN O 365 R -46) (comment otilde)
   (KRN O 362 R -46) (comment ograve)
   (KRN O 366 R -46) (comment odieresis)
   (KRN O 364 R -46) (comment ocircumflex)
   (KRN O 363 R -46) (comment oacute)
   (KRN O 354 R -10) (comment igrave)
   (KRN O 357 R -10) (comment idieresis)
   (KRN O 356 R -10) (comment icircumflex)
   (KRN O 355 R -10) (comment iacute)
   (KRN O 350 R -54) (comment egrave)
   (KRN O 353 R -54) (comment edieresis)
   (KRN O 352 R -54) (comment ecircumflex)
   (KRN O 351 R -54) (comment eacute)
   (KRN O 307 R -34) (comment Ccedilla)
   (KRN O 343 R -43) (comment atilde)
   (KRN O 345 R -43) (comment aring)
   (KRN O 340 R -43) (comment agrave)
   (KRN O 344 R -43) (comment adieresis)
   (KRN O 342 R -43) (comment acircumflex)
   (KRN O 341 R -43) (comment aacute)
   (KRN O 54 R -38) (comment comma)
   (KRN O 55 R -35) (comment hyphen)
   (KRN O 56 R -39) (comment period)
   (KRN O 72 R -22) (comment colon)
   (KRN O 73 R -23) (comment semicolon)
   (KRN C A R -34)
   (KRN C C R -34)
   (KRN C G R -30)
   (KRN C O R -32)
   (KRN C S R -22)
   (KRN C T R 8)
   (KRN C a R -43)
   (KRN C e R -54)
   (KRN C g R -50)
   (KRN C i R -10)
   (KRN C o R -46)
   (KRN C p R -41)
   (KRN C u R -42)
   (KRN C v R -38)
   (KRN O 23 R -61) (comment guillemotleft)
   (KRN O 300 R -34) (comment Agrave)
   (KRN O 301 R -34) (comment Aacute)
   (KRN O 302 R -34) (comment Acircumflex)
   (KRN O 303 R -34) (comment Atilde)
   (KRN O 304 R -34) (comment Adieresis)
   (KRN O 305 R -34) (comment Aring)
   (KRN O 306 R -35) (comment AE)
   (KRN O 322 R -32) (comment Ograve)
   (KRN O 323 R -32) (comment Oacute)
   (KRN O 324 R -32) (comment Ocircumflex)
   (KRN O 325 R -32) (comment Otilde)
   (KRN O 326 R -32) (comment Odieresis)
   (KRN O 330 R -36) (comment Oslash)
   (KRN O 346 R -50) (comment ae)
   (KRN O 370 R -50) (comment oslash)
   (KRN O 16 R -69) (comment guilsinglleft)
   (STOP)
   (LABEL C Z)
   (KRN O 270 R -22) (comment ydieresis)
   (KRN O 375 R -22) (comment yacute)
   (KRN C v R -14)
   (KRN C w R -14)
   (KRN C y R -22)
   (STOP)
   (LABEL O 140) (comment quoteleft)
   (LIG O 140 O 20)
   (KRN O 230 R -6) (comment Ydieresis)
   (KRN O 335 R -6) (comment Yacute)
   (KRN O 303 R -50) (comment Atilde)
   (KRN C A R -50)
   (KRN C T R -5)
   (KRN C V R -3)
   (KRN C W R -2)
   (KRN C Y R -6)
   (KRN O 300 R -50) (comment Agrave)
   (KRN O 301 R -50) (comment Aacute)
   (KRN O 302 R -50) (comment Acircumflex)
   (KRN O 304 R -50) (comment Adieresis)
   (KRN O 305 R -50) (comment Aring)
   (KRN O 306 R -65) (comment AE)
   (STOP)
   (LABEL C a)
   (KRN O 270 R -2) (comment ydieresis)
   (KRN O 375 R -2) (comment yacute)
   (KRN C j R 1)
   (KRN C v R -2)
   (KRN C w R -2)
   (KRN C y R -2)
   (KRN O 47 R -14) (comment quoteright)
   (STOP)
   (LABEL C b)
   (KRN O 270 R -11) (comment ydieresis)
   (KRN O 375 R -11) (comment yacute)
   (KRN C v R -12)
   (KRN C w R -12)
   (KRN C y R -11)
   (STOP)
   (LABEL C c)
   (KRN C h R -12)
   (KRN C k R -8)
   (STOP)
   (LABEL C e)
   (KRN O 270 R -2) (comment ydieresis)
   (KRN O 375 R -2) (comment yacute)
   (KRN C t R 1)
   (KRN C v R -4)
   (KRN C w R -4)
   (KRN C x R -11)
   (KRN C y R -2)
   (KRN O 47 R -8) (comment quoteright)
   (STOP)
   (LABEL C f)
   (LIG C f O 33)
   (LIG C l O 35)
   (LIG C i O 34)
   (KRN O 262 R -8) (comment scaron)
   (KRN O 365 R -14) (comment otilde)
   (KRN O 353 R -20) (comment edieresis)
   (KRN O 343 R -10) (comment atilde)
   (KRN O 340 R -10) (comment agrave)
   (KRN O 342 R -10) (comment acircumflex)
   (KRN C a R -10)
   (KRN C e R -20)
   (KRN C j R 14)
   (KRN C o R -14)
   (KRN C s R -8)
   (KRN C t R 10)
   (KRN O 341 R -10) (comment aacute)
   (KRN O 344 R 14) (comment adieresis)
   (KRN O 345 R -10) (comment aring)
   (KRN O 346 R -17) (comment ae)
   (KRN O 350 R -4) (comment egrave)
   (KRN O 351 R -20) (comment eacute)
   (KRN O 352 R -11) (comment ecircumflex)
   (KRN O 362 R -10) (comment ograve)
   (KRN O 363 R -18) (comment oacute)
   (KRN O 364 R -11) (comment ocircumflex)
   (KRN O 366 R 23) (comment odieresis)
   (KRN O 370 R -18) (comment oslash)
   (KRN O 367 R -21) (comment oe)
   (KRN O 47 R 14) (comment quoteright)
   (STOP)
   (LABEL C g)
   (KRN O 343 R -18) (comment atilde)
   (KRN O 340 R -18) (comment agrave)
   (KRN O 342 R -18) (comment acircumflex)
   (KRN O 341 R -18) (comment aacute)
   (KRN C a R -18)
   (KRN C e R -25)
   (KRN C l R -17)
   (KRN C r R 4)
   (KRN O 344 R -18) (comment adieresis)
   (KRN O 345 R -18) (comment aring)
   (KRN O 346 R -25) (comment ae)
   (KRN O 350 R -25) (comment egrave)
   (KRN O 351 R -25) (comment eacute)
   (KRN O 352 R -25) (comment ecircumflex)
   (KRN O 353 R -25) (comment edieresis)
   (KRN O 363 R -17) (comment oacute)
   (KRN O 366 R -17) (comment odieresis)
   (STOP)
   (LABEL C h)
   (KRN O 270 R -14) (comment ydieresis)
   (KRN O 375 R -14) (comment yacute)
   (KRN C y R -14)
   (KRN O 47 R -25) (comment quoteright)
   (STOP)
   (LABEL C i)
   (KRN C T R -16)
   (STOP)
   (LABEL C k)
   (KRN O 371 R 3) (comment ugrave)
   (KRN O 373 R 3) (comment ucircumflex)
   (KRN O 372 R 3) (comment uacute)
   (KRN O 262 R 3) (comment scaron)
   (KRN O 365 R 4) (comment otilde)
   (KRN O 370 R 4) (comment oslash)
   (KRN O 362 R 4) (comment ograve)
   (KRN O 364 R 4) (comment ocircumflex)
   (KRN O 343 R 14) (comment atilde)
   (KRN O 340 R 14) (comment agrave)
   (KRN O 342 R 14) (comment acircumflex)
   (KRN O 54 R 29) (comment comma)
   (KRN O 55 R 4) (comment hyphen)
   (KRN O 56 R 25) (comment period)
   (KRN C a R 14)
   (KRN C g R -10)
   (KRN C o R 4)
   (KRN C s R 3)
   (KRN C u R 3)
   (KRN O 341 R 14) (comment aacute)
   (KRN O 344 R 14) (comment adieresis)
   (KRN O 345 R 14) (comment aring)
   (KRN O 346 R 4) (comment ae)
   (KRN O 363 R 4) (comment oacute)
   (KRN O 366 R 4) (comment odieresis)
   (KRN O 374 R 3) (comment udieresis)
   (STOP)
   (LABEL C l)
   (KRN O 270 R -6) (comment ydieresis)
   (KRN O 375 R -6) (comment yacute)
   (KRN C v R -8)
   (KRN C y R -6)
   (STOP)
   (LABEL C m)
   (KRN O 270 R -11) (comment ydieresis)
   (KRN O 375 R -11) (comment yacute)
   (KRN C p R 5)
   (KRN C v R -11)
   (KRN C w R -13)
   (KRN C y R -11)
   (STOP)
   (LABEL C n)
   (KRN O 270 R -14) (comment ydieresis)
   (KRN O 375 R -14) (comment yacute)
   (KRN C T R -43)
   (KRN C p R 1)
   (KRN C v R -16)
   (KRN C w R -16)
   (KRN C y R -14)
   (KRN O 47 R -23) (comment quoteright)
   (STOP)
   (LABEL C o)
   (KRN O 270 R -16) (comment ydieresis)
   (KRN O 375 R -16) (comment yacute)
   (KRN C T R -47)
   (KRN C t R 4)
   (KRN C v R -15)
   (KRN C w R -15)
   (KRN C x R -18)
   (KRN C y R -16)
   (KRN O 47 R -14) (comment quoteright)
   (STOP)
   (LABEL C p)
   (KRN O 270 R -8) (comment ydieresis)
   (KRN O 375 R -8) (comment yacute)
   (KRN C t R 4)
   (KRN C y R -8)
   (STOP)
   (LABEL C q)
   (KRN O 371 R -2) (comment ugrave)
   (KRN O 374 R -2) (comment udieresis)
   (KRN O 373 R -2) (comment ucircumflex)
   (KRN O 372 R -2) (comment uacute)
   (KRN O 347 R -2) (comment ccedilla)
   (KRN C c R -2)
   (KRN C u R -2)
   (STOP)
   (LABEL C r)
   (KRN O 272 R 11) (comment zcaron)
   (KRN O 270 R 25) (comment ydieresis)
   (KRN O 375 R 25) (comment yacute)
   (KRN O 371 R 13) (comment ugrave)
   (KRN O 374 R 13) (comment udieresis)
   (KRN O 373 R 13) (comment ucircumflex)
   (KRN O 372 R 13) (comment uacute)
   (KRN O 365 R -9) (comment otilde)
   (KRN O 361 R 8) (comment ntilde)
   (KRN O 354 R 20) (comment igrave)
   (KRN O 357 R 20) (comment idieresis)
   (KRN O 356 R 20) (comment icircumflex)
   (KRN O 355 R 20) (comment iacute)
   (KRN O 353 R -17) (comment edieresis)
   (KRN O 343 R -10) (comment atilde)
   (KRN O 54 R -46) (comment comma)
   (KRN O 55 R -33) (comment hyphen)
   (KRN O 56 R -50) (comment period)
   (KRN O 72 R -12) (comment colon)
   (KRN O 73 R -14) (comment semicolon)
   (KRN C a R -10)
   (KRN C c R -12)
   (KRN C d R -10)
   (KRN C e R -17)
   (KRN C f R 9)
   (KRN C g R -3)
   (KRN C h R -12)
   (KRN C i R 20)
   (KRN C j R 14)
   (KRN C k R -10)
   (KRN C l R -10)
   (KRN C m R 13)
   (KRN C n R 8)
   (KRN C o R -9)
   (KRN C p R 19)
   (KRN C q R -18)
   (KRN C r R 18)
   (KRN C t R 15)
   (KRN C u R 13)
   (KRN C v R 23)
   (KRN C w R 23)
   (KRN C x R 8)
   (KRN C y R 25)
   (KRN C z R 11)
   (KRN O 340 R -10) (comment agrave)
   (KRN O 341 R -10) (comment aacute)
   (KRN O 342 R -10) (comment acircumflex)
   (KRN O 344 R -10) (comment adieresis)
   (KRN O 345 R -10) (comment aring)
   (KRN O 346 R -18) (comment ae)
   (KRN O 347 R -10) (comment ccedilla)
   (KRN O 350 R -17) (comment egrave)
   (KRN O 351 R -17) (comment eacute)
   (KRN O 352 R -17) (comment ecircumflex)
   (KRN O 362 R -9) (comment ograve)
   (KRN O 363 R -9) (comment oacute)
   (KRN O 364 R -9) (comment ocircumflex)
   (KRN O 366 R -9) (comment odieresis)
   (KRN O 370 R -10) (comment oslash)
   (KRN O 367 R -15) (comment oe)
   (KRN O 47 R 5) (comment quoteright)
   (STOP)
   (LABEL C s)
   (KRN C t R -2)
   (KRN O 47 R -14) (comment quoteright)
   (STOP)
   (LABEL C t)
   (KRN O 365 R 3) (comment otilde)
   (KRN O 370 R 3) (comment oslash)
   (KRN O 362 R 3) (comment ograve)
   (KRN O 364 R 3) (comment ocircumflex)
   (KRN O 350 R -1) (comment egrave)
   (KRN O 353 R -1) (comment edieresis)
   (KRN O 352 R -1) (comment ecircumflex)
   (KRN O 343 R 14) (comment atilde)
   (KRN O 340 R 14) (comment agrave)
   (KRN O 342 R 14) (comment acircumflex)
   (KRN O 72 R 24) (comment colon)
   (KRN O 73 R 21) (comment semicolon)
   (KRN C a R 14)
   (KRN C e R -1)
   (KRN C o R 3)
   (KRN O 341 R 14) (comment aacute)
   (KRN O 344 R 14) (comment adieresis)
   (KRN O 345 R 14) (comment aring)
   (KRN O 346 R 4) (comment ae)
   (KRN O 351 R -1) (comment eacute)
   (KRN O 363 R 3) (comment oacute)
   (KRN O 366 R 3) (comment odieresis)
   (KRN O 47 R -10) (comment quoteright)
   (STOP)
   (LABEL C u)
   (KRN O 47 R -24) (comment quoteright)
   (STOP)
   (LABEL C v)
   (KRN O 262 R -12) (comment scaron)
   (KRN O 365 R -13) (comment otilde)
   (KRN O 364 R -13) (comment ocircumflex)
   (KRN O 353 R -18) (comment edieresis)
   (KRN O 347 R -14) (comment ccedilla)
   (KRN O 54 R -35) (comment comma)
   (KRN O 56 R -37) (comment period)
   (KRN O 72 R -2) (comment colon)
   (KRN C a R -11)
   (KRN C c R -14)
   (KRN C e R -18)
   (KRN C g R -15)
   (KRN C l R -14)
   (KRN C o R -13)
   (KRN C s R -12)
   (KRN O 340 R -11) (comment agrave)
   (KRN O 341 R -11) (comment aacute)
   (KRN O 342 R -11) (comment acircumflex)
   (KRN O 343 R -11) (comment atilde)
   (KRN O 344 R -11) (comment adieresis)
   (KRN O 345 R -11) (comment aring)
   (KRN O 346 R -17) (comment ae)
   (KRN O 350 R -18) (comment egrave)
   (KRN O 351 R -18) (comment eacute)
   (KRN O 352 R -18) (comment ecircumflex)
   (KRN O 362 R -13) (comment ograve)
   (KRN O 363 R -13) (comment oacute)
   (KRN O 366 R -13) (comment odieresis)
   (KRN O 370 R -15) (comment oslash)
   (STOP)
   (LABEL C w)
   (KRN O 262 R -16) (comment scaron)
   (KRN O 365 R -16) (comment otilde)
   (KRN O 364 R -16) (comment ocircumflex)
   (KRN O 353 R -22) (comment edieresis)
   (KRN O 347 R -18) (comment ccedilla)
   (KRN O 54 R -35) (comment comma)
   (KRN O 55 R -6) (comment hyphen)
   (KRN O 56 R -37) (comment period)
   (KRN O 72 R -5) (comment colon)
   (KRN O 73 R -3) (comment semicolon)
   (KRN C a R -15)
   (KRN C c R -18)
   (KRN C e R -22)
   (KRN C g R -20)
   (KRN C l R -18)
   (KRN C o R -16)
   (KRN C s R -16)
   (KRN O 340 R -15) (comment agrave)
   (KRN O 341 R -15) (comment aacute)
   (KRN O 342 R -15) (comment acircumflex)
   (KRN O 343 R -15) (comment atilde)
   (KRN O 344 R -15) (comment adieresis)
   (KRN O 345 R -15) (comment aring)
   (KRN O 346 R -21) (comment ae)
   (KRN O 350 R -22) (comment egrave)
   (KRN O 351 R -22) (comment eacute)
   (KRN O 352 R -22) (comment ecircumflex)
   (KRN O 362 R -16) (comment ograve)
   (KRN O 363 R -16) (comment oacute)
   (KRN O 366 R -16) (comment odieresis)
   (KRN O 370 R -16) (comment oslash)
   (STOP)
   (LABEL C x)
   (KRN O 365 R -10) (comment otilde)
   (KRN O 370 R -10) (comment oslash)
   (KRN O 362 R -10) (comment ograve)
   (KRN O 366 R -10) (comment odieresis)
   (KRN O 364 R -10) (comment ocircumflex)
   (KRN O 363 R -10) (comment oacute)
   (KRN O 350 R -12) (comment egrave)
   (KRN O 353 R -12) (comment edieresis)
   (KRN O 352 R -12) (comment ecircumflex)
   (KRN O 347 R -9) (comment ccedilla)
   (KRN O 343 R -2) (comment atilde)
   (KRN O 345 R -2) (comment aring)
   (KRN O 340 R -2) (comment agrave)
   (KRN O 344 R -2) (comment adieresis)
   (KRN O 342 R -2) (comment acircumflex)
   (KRN O 341 R -2) (comment aacute)
   (KRN C a R -2)
   (KRN C c R -9)
   (KRN C e R -12)
   (KRN C o R -10)
   (KRN C q R -10)
   (KRN O 351 R -12) (comment eacute)
   (STOP)
   (LABEL C y)
   (KRN O 262 R -7) (comment scaron)
   (KRN O 365 R -6) (comment otilde)
   (KRN O 364 R -6) (comment ocircumflex)
   (KRN O 353 R -11) (comment edieresis)
   (KRN O 347 R -7) (comment ccedilla)
   (KRN O 54 R -14) (comment comma)
   (KRN O 55 R 4) (comment hyphen)
   (KRN O 56 R -16) (comment period)
   (KRN O 72 R 5) (comment colon)
   (KRN O 73 R 10) (comment semicolon)
   (KRN C a R -4)
   (KRN C c R -7)
   (KRN C e R -11)
   (KRN C g R -11)
   (KRN C l R -8)
   (KRN C o R -6)
   (KRN C s R -7)
   (KRN O 340 R -4) (comment agrave)
   (KRN O 341 R -4) (comment aacute)
   (KRN O 342 R -4) (comment acircumflex)
   (KRN O 343 R -4) (comment atilde)
   (KRN O 344 R -4) (comment adieresis)
   (KRN O 345 R -4) (comment aring)
   (KRN O 346 R -10) (comment ae)
   (KRN O 350 R -11) (comment egrave)
   (KRN O 351 R -11) (comment eacute)
   (KRN O 352 R -11) (comment ecircumflex)
   (KRN O 362 R -6) (comment ograve)
   (KRN O 363 R -6) (comment oacute)
   (KRN O 366 R -6) (comment odieresis)
   (KRN O 370 R -8) (comment oslash)
   (STOP)
   (LABEL O 222) (comment Scaron)
   (KRN O 230 R -18) (comment Ydieresis)
   (KRN O 335 R -18) (comment Yacute)
   (KRN O 306 R -13) (comment AE)
   (KRN O 305 R -11) (comment Aring)
   (KRN O 304 R -11) (comment Adieresis)
   (KRN O 301 R -11) (comment Aacute)
   (KRN C t R 5)
   (KRN C Y R -18)
   (KRN C W R -14)
   (KRN C V R -15)
   (KRN C T R -24)
   (KRN C A R -11)
   (KRN O 302 R -11) (comment Acircumflex)
   (KRN O 300 R -11) (comment Agrave)
   (KRN O 303 R -11) (comment Atilde)
   (STOP)
   (LABEL O 230) (comment Ydieresis)
   (KRN O 16 R -69) (comment guilsinglleft)
   (KRN O 370 R -50) (comment oslash)
   (KRN O 346 R -50) (comment ae)
   (KRN O 330 R -36) (comment Oslash)
   (KRN O 326 R -32) (comment Odieresis)
   (KRN O 325 R -32) (comment Otilde)
   (KRN O 324 R -32) (comment Ocircumflex)
   (KRN O 323 R -32) (comment Oacute)
   (KRN O 322 R -32) (comment Ograve)
   (KRN O 306 R -35) (comment AE)
   (KRN O 305 R -34) (comment Aring)
   (KRN O 304 R -34) (comment Adieresis)
   (KRN O 303 R -34) (comment Atilde)
   (KRN O 302 R -34) (comment Acircumflex)
   (KRN O 301 R -34) (comment Aacute)
   (KRN O 300 R -34) (comment Agrave)
   (KRN O 23 R -61) (comment guillemotleft)
   (KRN C v R -38)
   (KRN C u R -42)
   (KRN C p R -41)
   (KRN C o R -46)
   (KRN C i R -10)
   (KRN C g R -50)
   (KRN C e R -54)
   (KRN C a R -43)
   (KRN C T R 8)
   (KRN C S R -22)
   (KRN C O R -32)
   (KRN C G R -30)
   (KRN C C R -34)
   (KRN C A R -34)
   (KRN O 73 R -23) (comment semicolon)
   (KRN O 72 R -22) (comment colon)
   (KRN O 56 R -39) (comment period)
   (KRN O 55 R -35) (comment hyphen)
   (KRN O 54 R -38) (comment comma)
   (KRN O 341 R -43) (comment aacute)
   (KRN O 342 R -43) (comment acircumflex)
   (KRN O 344 R -43) (comment adieresis)
   (KRN O 340 R -43) (comment agrave)
   (KRN O 345 R -43) (comment aring)
   (KRN O 343 R -43) (comment atilde)
   (KRN O 307 R -34) (comment Ccedilla)
   (KRN O 351 R -54) (comment eacute)
   (KRN O 352 R -54) (comment ecircumflex)
   (KRN O 353 R -54) (comment edieresis)
   (KRN O 350 R -54) (comment egrave)
   (KRN O 355 R -10) (comment iacute)
   (KRN O 356 R -10) (comment icircumflex)
   (KRN O 357 R -10) (comment idieresis)
   (KRN O 354 R -10) (comment igrave)
   (KRN O 363 R -46) (comment oacute)
   (KRN O 364 R -46) (comment ocircumflex)
   (KRN O 366 R -46) (comment odieresis)
   (KRN O 362 R -46) (comment ograve)
   (KRN O 365 R -46) (comment otilde)
   (KRN O 222 R -22) (comment Scaron)
   (KRN O 372 R -42) (comment uacute)
   (KRN O 373 R -42) (comment ucircumflex)
   (KRN O 374 R -42) (comment udieresis)
   (KRN O 371 R -42) (comment ugrave)
   (STOP)
   (LABEL O 232) (comment Zcaron)
   (KRN C y R -22)
   (KRN C w R -14)
   (KRN C v R -14)
   (KRN O 375 R -22) (comment yacute)
   (KRN O 270 R -22) (comment ydieresis)
   (STOP)
   (LABEL O 262) (comment scaron)
   (KRN O 47 R -14) (comment quoteright)
   (KRN C t R -2)
   (STOP)
   (LABEL O 270) (comment ydieresis)
   (KRN O 370 R -8) (comment oslash)
   (KRN O 366 R -6) (comment odieresis)
   (KRN O 363 R -6) (comment oacute)
   (KRN O 362 R -6) (comment ograve)
   (KRN O 352 R -11) (comment ecircumflex)
   (KRN O 351 R -11) (comment eacute)
   (KRN O 350 R -11) (comment egrave)
   (KRN O 346 R -10) (comment ae)
   (KRN O 345 R -4) (comment aring)
   (KRN O 344 R -4) (comment adieresis)
   (KRN O 343 R -4) (comment atilde)
   (KRN O 342 R -4) (comment acircumflex)
   (KRN O 341 R -4) (comment aacute)
   (KRN O 340 R -4) (comment agrave)
   (KRN C s R -7)
   (KRN C o R -6)
   (KRN C l R -8)
   (KRN C g R -11)
   (KRN C e R -11)
   (KRN C c R -7)
   (KRN C a R -4)
   (KRN O 73 R 10) (comment semicolon)
   (KRN O 72 R 5) (comment colon)
   (KRN O 56 R -16) (comment period)
   (KRN O 55 R 4) (comment hyphen)
   (KRN O 54 R -14) (comment comma)
   (KRN O 347 R -7) (comment ccedilla)
   (KRN O 353 R -11) (comment edieresis)
   (KRN O 364 R -6) (comment ocircumflex)
   (KRN O 365 R -6) (comment otilde)
   (KRN O 262 R -7) (comment scaron)
   (STOP)
   (LABEL O 300) (comment Agrave)
   (KRN O 270 R -41) (comment ydieresis)
   (KRN O 230 R -100) (comment Ydieresis)
   (KRN O 375 R -41) (comment yacute)
   (KRN O 335 R -100) (comment Yacute)
   (KRN O 365 R -16) (comment otilde)
   (KRN O 325 R -36) (comment Otilde)
   (KRN O 370 R -16) (comment oslash)
   (KRN O 330 R -36) (comment Oslash)
   (KRN O 362 R -16) (comment ograve)
   (KRN O 322 R -36) (comment Ograve)
   (KRN O 364 R -16) (comment ocircumflex)
   (KRN O 324 R -36) (comment Ocircumflex)
   (KRN O 363 R -16) (comment oacute)
   (KRN O 323 R -36) (comment Oacute)
   (KRN O 350 R -17) (comment egrave)
   (KRN O 353 R -17) (comment edieresis)
   (KRN O 352 R -17) (comment ecircumflex)
   (KRN O 351 R -17) (comment eacute)
   (KRN O 343 R -4) (comment atilde)
   (KRN O 345 R -4) (comment aring)
   (KRN O 340 R -4) (comment agrave)
   (KRN O 16 R -41) (comment guilsinglleft)
   (KRN O 21 R -49) (comment quotedblright)
   (KRN O 47 R -66) (comment quoteright)
   (KRN O 374 R -14) (comment udieresis)
   (KRN O 373 R -14) (comment ucircumflex)
   (KRN O 372 R -14) (comment uacute)
   (KRN O 371 R -14) (comment ugrave)
   (KRN O 366 R -16) (comment odieresis)
   (KRN O 347 R -18) (comment ccedilla)
   (KRN O 334 R -65) (comment Udieresis)
   (KRN O 333 R -65) (comment Ucircumflex)
   (KRN O 332 R -65) (comment Uacute)
   (KRN O 331 R -65) (comment Ugrave)
   (KRN O 326 R -36) (comment Odieresis)
   (KRN O 307 R -38) (comment Ccedilla)
   (KRN O 23 R -34) (comment guillemotleft)
   (KRN C y R -41)
   (KRN C w R -37)
   (KRN C v R -34)
   (KRN C u R -14)
   (KRN C t R -3)
   (KRN C q R -12)
   (KRN C o R -16)
   (KRN C g R -16)
   (KRN C e R -17)
   (KRN C d R -3)
   (KRN C c R -14)
   (KRN C b R -2)
   (KRN C a R -4)
   (KRN O 55 R -6) (comment hyphen)
   (KRN O 341 R -4) (comment aacute)
   (KRN O 342 R -4) (comment acircumflex)
   (KRN O 344 R -4) (comment adieresis)
   (KRN O 54 R 13) (comment comma)
   (KRN O 56 R 18) (comment period)
   (KRN C C R -38)
   (KRN C G R -34)
   (KRN C O R -36)
   (KRN C Q R -36)
   (KRN C T R -55)
   (KRN C U R -65)
   (KRN C V R -105)
   (KRN C W R -105)
   (KRN C Y R -100)
   (STOP)
   (LABEL O 301) (comment Aacute)
   (KRN O 270 R -41) (comment ydieresis)
   (KRN O 230 R -100) (comment Ydieresis)
   (KRN O 375 R -41) (comment yacute)
   (KRN O 335 R -100) (comment Yacute)
   (KRN O 365 R -16) (comment otilde)
   (KRN O 325 R -36) (comment Otilde)
   (KRN O 370 R -16) (comment oslash)
   (KRN O 330 R -36) (comment Oslash)
   (KRN O 362 R -16) (comment ograve)
   (KRN O 322 R -36) (comment Ograve)
   (KRN O 364 R -16) (comment ocircumflex)
   (KRN O 324 R -36) (comment Ocircumflex)
   (KRN O 363 R -16) (comment oacute)
   (KRN O 323 R -36) (comment Oacute)
   (KRN O 350 R -17) (comment egrave)
   (KRN O 353 R -17) (comment edieresis)
   (KRN O 352 R -17) (comment ecircumflex)
   (KRN O 351 R -17) (comment eacute)
   (KRN O 343 R -4) (comment atilde)
   (KRN O 345 R -4) (comment aring)
   (KRN O 340 R -4) (comment agrave)
   (KRN O 344 R -4) (comment adieresis)
   (KRN O 342 R -4) (comment acircumflex)
   (KRN O 341 R -4) (comment aacute)
   (KRN O 374 R -14) (comment udieresis)
   (KRN O 373 R -14) (comment ucircumflex)
   (KRN O 372 R -14) (comment uacute)
   (KRN O 371 R -14) (comment ugrave)
   (KRN O 366 R -16) (comment odieresis)
   (KRN O 347 R -18) (comment ccedilla)
   (KRN O 334 R -65) (comment Udieresis)
   (KRN O 333 R -65) (comment Ucircumflex)
   (KRN O 332 R -65) (comment Uacute)
   (KRN O 331 R -65) (comment Ugrave)
   (KRN O 326 R -36) (comment Odieresis)
   (KRN O 307 R -38) (comment Ccedilla)
   (KRN O 54 R 13) (comment comma)
   (KRN O 55 R -6) (comment hyphen)
   (KRN O 56 R 18) (comment period)
   (KRN C C R -38)
   (KRN C G R -34)
   (KRN C O R -36)
   (KRN C Q R -36)
   (KRN C T R -55)
   (KRN C U R -65)
   (KRN C V R -105)
   (KRN C W R -105)
   (KRN C Y R -100)
   (KRN C a R -4)
   (KRN C b R -2)
   (KRN C c R -14)
   (KRN C d R -3)
   (KRN C e R -17)
   (KRN C g R -16)
   (KRN C o R -16)
   (KRN C q R -12)
   (KRN C t R -3)
   (KRN C u R -14)
   (KRN C v R -34)
   (KRN C w R -37)
   (KRN C y R -41)
   (KRN O 23 R -34) (comment guillemotleft)
   (KRN O 47 R -66) (comment quoteright)
   (KRN O 21 R -49) (comment quotedblright)
   (KRN O 16 R -41) (comment guilsinglleft)
   (STOP)
   (LABEL O 302) (comment Acircumflex)
   (KRN O 270 R -41) (comment ydieresis)
   (KRN O 230 R -100) (comment Ydieresis)
   (KRN O 375 R -41) (comment yacute)
   (KRN O 335 R -100) (comment Yacute)
   (KRN O 365 R -16) (comment otilde)
   (KRN O 325 R -36) (comment Otilde)
   (KRN O 370 R -16) (comment oslash)
   (KRN O 330 R -36) (comment Oslash)
   (KRN O 362 R -16) (comment ograve)
   (KRN O 322 R -36) (comment Ograve)
   (KRN O 364 R -16) (comment ocircumflex)
   (KRN O 324 R -36) (comment Ocircumflex)
   (KRN O 363 R -16) (comment oacute)
   (KRN O 323 R -36) (comment Oacute)
   (KRN O 350 R -17) (comment egrave)
   (KRN O 353 R -17) (comment edieresis)
   (KRN O 352 R -17) (comment ecircumflex)
   (KRN O 351 R -17) (comment eacute)
   (KRN O 343 R -4) (comment atilde)
   (KRN O 345 R -4) (comment aring)
   (KRN O 340 R -4) (comment agrave)
   (KRN O 344 R -4) (comment adieresis)
   (KRN O 342 R -4) (comment acircumflex)
   (KRN O 16 R -41) (comment guilsinglleft)
   (KRN O 21 R -49) (comment quotedblright)
   (KRN O 47 R -66) (comment quoteright)
   (KRN O 374 R -14) (comment udieresis)
   (KRN O 373 R -14) (comment ucircumflex)
   (KRN O 372 R -14) (comment uacute)
   (KRN O 371 R -14) (comment ugrave)
   (KRN O 366 R -16) (comment odieresis)
   (KRN O 347 R -18) (comment ccedilla)
   (KRN O 334 R -65) (comment Udieresis)
   (KRN O 333 R -65) (comment Ucircumflex)
   (KRN O 332 R -65) (comment Uacute)
   (KRN O 331 R -65) (comment Ugrave)
   (KRN O 326 R -36) (comment Odieresis)
   (KRN O 307 R -38) (comment Ccedilla)
   (KRN O 23 R -34) (comment guillemotleft)
   (KRN C y R -41)
   (KRN C w R -37)
   (KRN C v R -34)
   (KRN C u R -14)
   (KRN C t R -3)
   (KRN C q R -12)
   (KRN C o R -16)
   (KRN C g R -16)
   (KRN C e R -17)
   (KRN C d R -3)
   (KRN C c R -14)
   (KRN C b R -2)
   (KRN C a R -4)
   (KRN O 55 R -6) (comment hyphen)
   (KRN O 341 R -4) (comment aacute)
   (KRN O 54 R 13) (comment comma)
   (KRN O 56 R 18) (comment period)
   (KRN C C R -38)
   (KRN C G R -34)
   (KRN C O R -36)
   (KRN C Q R -36)
   (KRN C T R -55)
   (KRN C U R -65)
   (KRN C V R -105)
   (KRN C W R -105)
   (KRN C Y R -100)
   (STOP)
   (LABEL O 303) (comment Atilde)
   (KRN O 270 R -41) (comment ydieresis)
   (KRN O 230 R -100) (comment Ydieresis)
   (KRN O 375 R -41) (comment yacute)
   (KRN O 335 R -100) (comment Yacute)
   (KRN O 365 R -16) (comment otilde)
   (KRN O 325 R -38) (comment Otilde)
   (KRN O 370 R -16) (comment oslash)
   (KRN O 330 R -38) (comment Oslash)
   (KRN O 362 R -16) (comment ograve)
   (KRN O 322 R -38) (comment Ograve)
   (KRN O 364 R -16) (comment ocircumflex)
   (KRN O 324 R -38) (comment Ocircumflex)
   (KRN O 363 R -16) (comment oacute)
   (KRN O 323 R -38) (comment Oacute)
   (KRN O 350 R -17) (comment egrave)
   (KRN O 353 R -17) (comment edieresis)
   (KRN O 352 R -17) (comment ecircumflex)
   (KRN O 351 R -17) (comment eacute)
   (KRN O 343 R -4) (comment atilde)
   (KRN O 16 R -41) (comment guilsinglleft)
   (KRN O 21 R -49) (comment quotedblright)
   (KRN O 47 R -66) (comment quoteright)
   (KRN O 374 R -14) (comment udieresis)
   (KRN O 373 R -14) (comment ucircumflex)
   (KRN O 372 R -14) (comment uacute)
   (KRN O 371 R -14) (comment ugrave)
   (KRN O 366 R -16) (comment odieresis)
   (KRN O 347 R -18) (comment ccedilla)
   (KRN O 334 R -65) (comment Udieresis)
   (KRN O 333 R -65) (comment Ucircumflex)
   (KRN O 332 R -65) (comment Uacute)
   (KRN O 331 R -65) (comment Ugrave)
   (KRN O 326 R -36) (comment Odieresis)
   (KRN O 307 R -38) (comment Ccedilla)
   (KRN O 23 R -34) (comment guillemotleft)
   (KRN C y R -41)
   (KRN C w R -37)
   (KRN C v R -34)
   (KRN C u R -14)
   (KRN C t R -3)
   (KRN C q R -12)
   (KRN C o R -16)
   (KRN C g R -16)
   (KRN C e R -17)
   (KRN C d R -3)
   (KRN C c R -14)
   (KRN C b R -2)
   (KRN C a R -4)
   (KRN O 55 R -6) (comment hyphen)
   (KRN O 341 R -4) (comment aacute)
   (KRN O 342 R -4) (comment acircumflex)
   (KRN O 344 R -4) (comment adieresis)
   (KRN O 340 R -4) (comment agrave)
   (KRN O 345 R -4) (comment aring)
   (KRN O 54 R 10) (comment comma)
   (KRN O 56 R 10) (comment period)
   (KRN C C R -37)
   (KRN C G R -33)
   (KRN C O R -38)
   (KRN C Q R -38)
   (KRN C T R -55)
   (KRN C U R -67)
   (KRN C V R -105)
   (KRN C W R -105)
   (KRN C Y R -100)
   (STOP)
   (LABEL O 304) (comment Adieresis)
   (KRN O 270 R -43) (comment ydieresis)
   (KRN O 230 R -80) (comment Ydieresis)
   (KRN O 375 R -43) (comment yacute)
   (KRN O 335 R -80) (comment Yacute)
   (KRN O 365 R -15) (comment otilde)
   (KRN O 325 R -37) (comment Otilde)
   (KRN O 370 R -15) (comment oslash)
   (KRN O 330 R -37) (comment Oslash)
   (KRN O 362 R -15) (comment ograve)
   (KRN O 322 R -37) (comment Ograve)
   (KRN O 364 R -15) (comment ocircumflex)
   (KRN O 324 R -37) (comment Ocircumflex)
   (KRN O 363 R -15) (comment oacute)
   (KRN O 323 R -37) (comment Oacute)
   (KRN O 350 R -17) (comment egrave)
   (KRN O 353 R -17) (comment edieresis)
   (KRN O 352 R -17) (comment ecircumflex)
   (KRN O 351 R -17) (comment eacute)
   (KRN O 343 R -4) (comment atilde)
   (KRN O 345 R -4) (comment aring)
   (KRN O 340 R -4) (comment agrave)
   (KRN O 344 R -4) (comment adieresis)
   (KRN O 374 R -14) (comment udieresis)
   (KRN O 373 R -14) (comment ucircumflex)
   (KRN O 372 R -14) (comment uacute)
   (KRN O 371 R -14) (comment ugrave)
   (KRN O 366 R -16) (comment odieresis)
   (KRN O 347 R -18) (comment ccedilla)
   (KRN O 334 R -65) (comment Udieresis)
   (KRN O 333 R -65) (comment Ucircumflex)
   (KRN O 332 R -65) (comment Uacute)
   (KRN O 331 R -65) (comment Ugrave)
   (KRN O 326 R -36) (comment Odieresis)
   (KRN O 307 R -38) (comment Ccedilla)
   (KRN C e R -17)
   (KRN O 342 R -4) (comment acircumflex)
   (KRN O 341 R -4) (comment aacute)
   (KRN O 54 R 11) (comment comma)
   (KRN O 55 R -7) (comment hyphen)
   (KRN O 56 R 14) (comment period)
   (KRN C C R -35)
   (KRN C G R -34)
   (KRN C O R -37)
   (KRN C Q R -37)
   (KRN C T R -55)
   (KRN C U R -65)
   (KRN C V R -75)
   (KRN C W R -75)
   (KRN C Y R -80)
   (KRN C a R -4)
   (KRN C b R -2)
   (KRN C c R -14)
   (KRN C d R -3)
   (KRN C g R -16)
   (KRN C o R -15)
   (KRN C q R -12)
   (KRN C t R -3)
   (KRN C u R -14)
   (KRN C v R -34)
   (KRN C w R -34)
   (KRN C y R -43)
   (KRN O 23 R -34) (comment guillemotleft)
   (KRN O 47 R -63) (comment quoteright)
   (KRN O 21 R -46) (comment quotedblright)
   (KRN O 16 R -42) (comment guilsinglleft)
   (STOP)
   (LABEL O 305) (comment Aring)
   (KRN O 270 R -41) (comment ydieresis)
   (KRN O 230 R -100) (comment Ydieresis)
   (KRN O 375 R -41) (comment yacute)
   (KRN O 335 R -100) (comment Yacute)
   (KRN O 365 R -16) (comment otilde)
   (KRN O 325 R -36) (comment Otilde)
   (KRN O 370 R -16) (comment oslash)
   (KRN O 330 R -36) (comment Oslash)
   (KRN O 362 R -16) (comment ograve)
   (KRN O 322 R -36) (comment Ograve)
   (KRN O 364 R -16) (comment ocircumflex)
   (KRN O 324 R -36) (comment Ocircumflex)
   (KRN O 363 R -16) (comment oacute)
   (KRN O 323 R -36) (comment Oacute)
   (KRN O 350 R -17) (comment egrave)
   (KRN O 353 R -17) (comment edieresis)
   (KRN O 352 R -17) (comment ecircumflex)
   (KRN O 351 R -17) (comment eacute)
   (KRN O 343 R -4) (comment atilde)
   (KRN O 345 R -4) (comment aring)
   (KRN O 374 R -14) (comment udieresis)
   (KRN O 373 R -14) (comment ucircumflex)
   (KRN O 372 R -14) (comment uacute)
   (KRN O 371 R -14) (comment ugrave)
   (KRN O 366 R -16) (comment odieresis)
   (KRN O 347 R -18) (comment ccedilla)
   (KRN O 334 R -65) (comment Udieresis)
   (KRN O 333 R -65) (comment Ucircumflex)
   (KRN O 332 R -65) (comment Uacute)
   (KRN O 331 R -65) (comment Ugrave)
   (KRN O 326 R -36) (comment Odieresis)
   (KRN O 307 R -38) (comment Ccedilla)
   (KRN O 340 R -4) (comment agrave)
   (KRN O 344 R -4) (comment adieresis)
   (KRN O 342 R -4) (comment acircumflex)
   (KRN O 341 R -4) (comment aacute)
   (KRN O 54 R 13) (comment comma)
   (KRN O 55 R -6) (comment hyphen)
   (KRN O 56 R 18) (comment period)
   (KRN C C R -38)
   (KRN C G R -34)
   (KRN C O R -36)
   (KRN C Q R -36)
   (KRN C T R -55)
   (KRN C U R -65)
   (KRN C V R -105)
   (KRN C W R -105)
   (KRN C Y R -100)
   (KRN C a R -4)
   (KRN C b R -2)
   (KRN C c R -14)
   (KRN C d R -3)
   (KRN C e R -17)
   (KRN C g R -16)
   (KRN C o R -16)
   (KRN C q R -12)
   (KRN C t R -3)
   (KRN C u R -14)
   (KRN C v R -34)
   (KRN C w R -37)
   (KRN C y R -41)
   (KRN O 23 R -34) (comment guillemotleft)
   (KRN O 47 R -66) (comment quoteright)
   (KRN O 21 R -49) (comment quotedblright)
   (KRN O 16 R -41) (comment guilsinglleft)
   (STOP)
   (LABEL O 307) (comment Ccedilla)
   (KRN O 325 R -7) (comment Otilde)
   (KRN O 330 R -7) (comment Oslash)
   (KRN O 324 R -7) (comment Ocircumflex)
   (KRN O 326 R -7) (comment Odieresis)
   (KRN O 323 R -7) (comment Oacute)
   (KRN O 322 R -7) (comment Ograve)
   (KRN O 306 R -23) (comment AE)
   (KRN C O R -7)
   (KRN C K R -13)
   (KRN C H R -12)
   (KRN O 303 R -22) (comment Atilde)
   (KRN O 305 R -22) (comment Aring)
   (KRN O 300 R -22) (comment Agrave)
   (KRN O 304 R -22) (comment Adieresis)
   (KRN O 302 R -22) (comment Acircumflex)
   (KRN O 301 R -22) (comment Aacute)
   (KRN C A R -22)
   (STOP)
   (LABEL O 321) (comment Ntilde)
   (KRN O 371 R -15) (comment ugrave)
   (KRN O 373 R -15) (comment ucircumflex)
   (KRN O 372 R -15) (comment uacute)
   (KRN O 365 R -11) (comment otilde)
   (KRN O 325 R -11) (comment Otilde)
   (KRN O 330 R -11) (comment Oslash)
   (KRN O 362 R -11) (comment ograve)
   (KRN O 322 R -11) (comment Ograve)
   (KRN O 364 R -11) (comment ocircumflex)
   (KRN O 324 R -11) (comment Ocircumflex)
   (KRN O 374 R -15) (comment udieresis)
   (KRN O 370 R -15) (comment oslash)
   (KRN O 366 R -15) (comment odieresis)
   (KRN O 363 R -15) (comment oacute)
   (KRN O 351 R -18) (comment eacute)
   (KRN O 346 R -14) (comment ae)
   (KRN O 345 R -12) (comment aring)
   (KRN O 344 R -12) (comment adieresis)
   (KRN O 341 R -12) (comment aacute)
   (KRN O 326 R -11) (comment Odieresis)
   (KRN O 323 R -11) (comment Oacute)
   (KRN O 307 R -10) (comment Ccedilla)
   (KRN O 306 R -30) (comment AE)
   (KRN O 305 R -29) (comment Aring)
   (KRN O 304 R -29) (comment Adieresis)
   (KRN O 301 R -29) (comment Aacute)
   (KRN C u R -15)
   (KRN C o R -11)
   (KRN C e R -18)
   (KRN C a R -8)
   (KRN C O R -11)
   (KRN C G R -6)
   (KRN C C R -10)
   (KRN C A R -29)
   (KRN O 56 R -8) (comment period)
   (KRN O 54 R -4) (comment comma)
   (KRN O 302 R -29) (comment Acircumflex)
   (KRN O 342 R -8) (comment acircumflex)
   (KRN O 300 R -29) (comment Agrave)
   (KRN O 340 R -8) (comment agrave)
   (KRN O 303 R -29) (comment Atilde)
   (KRN O 343 R -8) (comment atilde)
   (KRN O 352 R -18) (comment ecircumflex)
   (KRN O 353 R -18) (comment edieresis)
   (KRN O 350 R -18) (comment egrave)
   (STOP)
   (LABEL O 322) (comment Ograve)
   (KRN O 230 R -36) (comment Ydieresis)
   (KRN O 335 R -36) (comment Yacute)
   (KRN O 306 R -40) (comment AE)
   (KRN O 305 R -30) (comment Aring)
   (KRN O 304 R -30) (comment Adieresis)
   (KRN O 301 R -30) (comment Aacute)
   (KRN C X R -35)
   (KRN C W R -30)
   (KRN C A R -30)
   (KRN O 302 R -30) (comment Acircumflex)
   (KRN O 300 R -30) (comment Agrave)
   (KRN O 303 R -30) (comment Atilde)
   (KRN C T R -15)
   (KRN C V R -31)
   (KRN C Y R -36)
   (STOP)
   (LABEL O 323) (comment Oacute)
   (KRN O 230 R -36) (comment Ydieresis)
   (KRN O 335 R -36) (comment Yacute)
   (KRN O 306 R -40) (comment AE)
   (KRN C X R -35)
   (KRN O 303 R -30) (comment Atilde)
   (KRN O 305 R -30) (comment Aring)
   (KRN O 300 R -30) (comment Agrave)
   (KRN O 304 R -30) (comment Adieresis)
   (KRN O 302 R -30) (comment Acircumflex)
   (KRN O 301 R -30) (comment Aacute)
   (KRN C A R -30)
   (KRN C T R -15)
   (KRN C V R -31)
   (KRN C W R -30)
   (KRN C Y R -36)
   (STOP)
   (LABEL O 324) (comment Ocircumflex)
   (KRN O 230 R -36) (comment Ydieresis)
   (KRN O 335 R -36) (comment Yacute)
   (KRN O 306 R -40) (comment AE)
   (KRN O 305 R -30) (comment Aring)
   (KRN O 304 R -30) (comment Adieresis)
   (KRN O 301 R -30) (comment Aacute)
   (KRN C X R -35)
   (KRN C W R -30)
   (KRN C A R -30)
   (KRN O 302 R -30) (comment Acircumflex)
   (KRN O 300 R -30) (comment Agrave)
   (KRN O 303 R -30) (comment Atilde)
   (KRN C T R -15)
   (KRN C V R -31)
   (KRN C Y R -36)
   (STOP)
   (LABEL O 325) (comment Otilde)
   (KRN O 230 R -36) (comment Ydieresis)
   (KRN O 335 R -36) (comment Yacute)
   (KRN O 306 R -40) (comment AE)
   (KRN O 305 R -30) (comment Aring)
   (KRN O 304 R -30) (comment Adieresis)
   (KRN O 301 R -30) (comment Aacute)
   (KRN C X R -35)
   (KRN C W R -30)
   (KRN C A R -30)
   (KRN O 302 R -30) (comment Acircumflex)
   (KRN O 300 R -30) (comment Agrave)
   (KRN O 303 R -30) (comment Atilde)
   (KRN C T R -15)
   (KRN C V R -31)
   (KRN C Y R -36)
   (STOP)
   (LABEL O 326) (comment Odieresis)
   (KRN O 230 R -36) (comment Ydieresis)
   (KRN O 335 R -36) (comment Yacute)
   (KRN O 306 R -40) (comment AE)
   (KRN O 303 R -30) (comment Atilde)
   (KRN O 305 R -30) (comment Aring)
   (KRN O 300 R -30) (comment Agrave)
   (KRN O 304 R -30) (comment Adieresis)
   (KRN O 302 R -30) (comment Acircumflex)
   (KRN O 301 R -30) (comment Aacute)
   (KRN C A R -30)
   (KRN C T R -15)
   (KRN C V R -31)
   (KRN C W R -30)
   (KRN C X R -35)
   (KRN C Y R -36)
   (STOP)
   (LABEL O 330) (comment Oslash)
   (KRN O 230 R -36) (comment Ydieresis)
   (KRN O 335 R -36) (comment Yacute)
   (KRN O 306 R -40) (comment AE)
   (KRN C Y R -36)
   (KRN C X R -35)
   (KRN C W R -30)
   (KRN C V R -31)
   (KRN C T R -15)
   (KRN O 303 R -30) (comment Atilde)
   (KRN O 305 R -30) (comment Aring)
   (KRN O 300 R -30) (comment Agrave)
   (KRN O 304 R -30) (comment Adieresis)
   (KRN O 302 R -30) (comment Acircumflex)
   (KRN O 301 R -30) (comment Aacute)
   (KRN C A R -30)
   (STOP)
   (LABEL O 331) (comment Ugrave)
   (KRN O 306 R -51) (comment AE)
   (KRN O 361 R -22) (comment ntilde)
   (KRN O 303 R -41) (comment Atilde)
   (KRN O 305 R -41) (comment Aring)
   (KRN O 300 R -41) (comment Agrave)
   (KRN O 304 R -41) (comment Adieresis)
   (KRN O 302 R -41) (comment Acircumflex)
   (KRN O 301 R -41) (comment Aacute)
   (KRN O 54 R -18) (comment comma)
   (KRN O 56 R -17) (comment period)
   (KRN C A R -41)
   (KRN C m R -19)
   (KRN C n R -22)
   (KRN C p R -16)
   (KRN C r R -17)
   (STOP)
   (LABEL O 332) (comment Uacute)
   (KRN O 306 R -51) (comment AE)
   (KRN O 361 R -22) (comment ntilde)
   (KRN O 303 R -41) (comment Atilde)
   (KRN O 305 R -41) (comment Aring)
   (KRN O 300 R -41) (comment Agrave)
   (KRN O 304 R -41) (comment Adieresis)
   (KRN O 302 R -41) (comment Acircumflex)
   (KRN O 301 R -41) (comment Aacute)
   (KRN O 54 R -18) (comment comma)
   (KRN O 56 R -17) (comment period)
   (KRN C A R -41)
   (KRN C m R -19)
   (KRN C n R -22)
   (KRN C p R -16)
   (KRN C r R -17)
   (STOP)
   (LABEL O 333) (comment Ucircumflex)
   (KRN O 306 R -51) (comment AE)
   (KRN C r R -17)
   (KRN C p R -16)
   (KRN C n R -22)
   (KRN C m R -19)
   (KRN O 56 R -17) (comment period)
   (KRN O 54 R -18) (comment comma)
   (KRN O 361 R -22) (comment ntilde)
   (KRN O 303 R -41) (comment Atilde)
   (KRN O 305 R -41) (comment Aring)
   (KRN O 300 R -41) (comment Agrave)
   (KRN O 304 R -41) (comment Adieresis)
   (KRN O 302 R -41) (comment Acircumflex)
   (KRN O 301 R -41) (comment Aacute)
   (KRN C A R -41)
   (STOP)
   (LABEL O 334) (comment Udieresis)
   (KRN O 306 R -51) (comment AE)
   (KRN O 361 R -22) (comment ntilde)
   (KRN O 303 R -41) (comment Atilde)
   (KRN O 305 R -41) (comment Aring)
   (KRN O 300 R -41) (comment Agrave)
   (KRN O 304 R -41) (comment Adieresis)
   (KRN O 302 R -41) (comment Acircumflex)
   (KRN O 301 R -41) (comment Aacute)
   (KRN O 54 R -18) (comment comma)
   (KRN O 56 R -17) (comment period)
   (KRN C A R -41)
   (KRN C b R 1)
   (KRN C m R -19)
   (KRN C n R -22)
   (KRN C p R -16)
   (KRN C r R -17)
   (STOP)
   (LABEL O 335) (comment Yacute)
   (KRN O 16 R -69) (comment guilsinglleft)
   (KRN O 370 R -50) (comment oslash)
   (KRN O 346 R -50) (comment ae)
   (KRN O 330 R -36) (comment Oslash)
   (KRN O 326 R -32) (comment Odieresis)
   (KRN O 325 R -32) (comment Otilde)
   (KRN O 324 R -32) (comment Ocircumflex)
   (KRN O 323 R -32) (comment Oacute)
   (KRN O 322 R -32) (comment Ograve)
   (KRN O 306 R -35) (comment AE)
   (KRN O 305 R -34) (comment Aring)
   (KRN O 304 R -34) (comment Adieresis)
   (KRN O 303 R -34) (comment Atilde)
   (KRN O 302 R -34) (comment Acircumflex)
   (KRN O 301 R -34) (comment Aacute)
   (KRN O 300 R -34) (comment Agrave)
   (KRN O 23 R -61) (comment guillemotleft)
   (KRN C v R -38)
   (KRN C u R -42)
   (KRN C p R -41)
   (KRN C o R -46)
   (KRN C i R -10)
   (KRN C g R -50)
   (KRN C e R -54)
   (KRN C a R -43)
   (KRN C T R 8)
   (KRN C S R -22)
   (KRN C O R -32)
   (KRN C G R -30)
   (KRN C C R -34)
   (KRN C A R -34)
   (KRN O 73 R -23) (comment semicolon)
   (KRN O 72 R -22) (comment colon)
   (KRN O 56 R -39) (comment period)
   (KRN O 55 R -35) (comment hyphen)
   (KRN O 54 R -38) (comment comma)
   (KRN O 341 R -43) (comment aacute)
   (KRN O 342 R -43) (comment acircumflex)
   (KRN O 344 R -43) (comment adieresis)
   (KRN O 340 R -43) (comment agrave)
   (KRN O 345 R -43) (comment aring)
   (KRN O 343 R -43) (comment atilde)
   (KRN O 307 R -34) (comment Ccedilla)
   (KRN O 351 R -54) (comment eacute)
   (KRN O 352 R -54) (comment ecircumflex)
   (KRN O 353 R -54) (comment edieresis)
   (KRN O 350 R -54) (comment egrave)
   (KRN O 355 R -10) (comment iacute)
   (KRN O 356 R -10) (comment icircumflex)
   (KRN O 357 R -10) (comment idieresis)
   (KRN O 354 R -10) (comment igrave)
   (KRN O 363 R -46) (comment oacute)
   (KRN O 364 R -46) (comment ocircumflex)
   (KRN O 366 R -46) (comment odieresis)
   (KRN O 362 R -46) (comment ograve)
   (KRN O 365 R -46) (comment otilde)
   (KRN O 222 R -22) (comment Scaron)
   (KRN O 372 R -42) (comment uacute)
   (KRN O 373 R -42) (comment ucircumflex)
   (KRN O 374 R -42) (comment udieresis)
   (KRN O 371 R -42) (comment ugrave)
   (STOP)
   (LABEL O 340) (comment agrave)
   (KRN O 270 R -2) (comment ydieresis)
   (KRN O 375 R -2) (comment yacute)
   (KRN O 47 R -14) (comment quoteright)
   (KRN C j R 1)
   (KRN C v R -2)
   (KRN C w R -2)
   (KRN C y R -2)
   (STOP)
   (LABEL O 341) (comment aacute)
   (KRN O 270 R -2) (comment ydieresis)
   (KRN O 375 R -2) (comment yacute)
   (KRN O 47 R -14) (comment quoteright)
   (KRN C j R 1)
   (KRN C v R -2)
   (KRN C w R -2)
   (KRN C y R -2)
   (STOP)
   (LABEL O 342) (comment acircumflex)
   (KRN O 270 R -2) (comment ydieresis)
   (KRN O 375 R -2) (comment yacute)
   (KRN O 47 R -14) (comment quoteright)
   (KRN C y R -2)
   (KRN C w R -2)
   (KRN C v R -2)
   (KRN C j R 1)
   (STOP)
   (LABEL O 343) (comment atilde)
   (KRN O 270 R -2) (comment ydieresis)
   (KRN O 375 R -2) (comment yacute)
   (KRN O 47 R -14) (comment quoteright)
   (KRN C y R -2)
   (KRN C w R -2)
   (KRN C v R -2)
   (KRN C j R 1)
   (STOP)
   (LABEL O 344) (comment adieresis)
   (KRN O 270 R -2) (comment ydieresis)
   (KRN O 375 R -2) (comment yacute)
   (KRN O 47 R -14) (comment quoteright)
   (KRN C j R 1)
   (KRN C v R -2)
   (KRN C w R -2)
   (KRN C y R -2)
   (STOP)
   (LABEL O 345) (comment aring)
   (KRN O 270 R -2) (comment ydieresis)
   (KRN O 375 R -2) (comment yacute)
   (KRN O 47 R -14) (comment quoteright)
   (KRN C j R 1)
   (KRN C v R -2)
   (KRN C w R -2)
   (KRN C y R -2)
   (STOP)
   (LABEL O 346) (comment ae)
   (KRN O 270 R -4) (comment ydieresis)
   (KRN O 375 R -4) (comment yacute)
   (KRN C v R -5)
   (KRN C w R -5)
   (KRN C y R -4)
   (STOP)
   (LABEL O 347) (comment ccedilla)
   (KRN C k R -8)
   (KRN C h R -12)
   (STOP)
   (LABEL O 350) (comment egrave)
   (KRN O 270 R -2) (comment ydieresis)
   (KRN O 375 R -2) (comment yacute)
   (KRN O 47 R -8) (comment quoteright)
   (KRN C y R -2)
   (KRN C x R -11)
   (KRN C w R -4)
   (KRN C v R -4)
   (KRN C t R 1)
   (STOP)
   (LABEL O 351) (comment eacute)
   (KRN O 270 R -2) (comment ydieresis)
   (KRN O 375 R -2) (comment yacute)
   (KRN O 47 R -8) (comment quoteright)
   (KRN C x R -11)
   (KRN C t R 1)
   (KRN C v R -4)
   (KRN C w R -4)
   (KRN C y R -2)
   (STOP)
   (LABEL O 352) (comment ecircumflex)
   (KRN O 270 R -2) (comment ydieresis)
   (KRN O 375 R -2) (comment yacute)
   (KRN O 47 R -8) (comment quoteright)
   (KRN C x R -11)
   (KRN C t R 1)
   (KRN C v R -4)
   (KRN C w R -4)
   (KRN C y R -2)
   (STOP)
   (LABEL O 353) (comment edieresis)
   (KRN O 270 R -2) (comment ydieresis)
   (KRN O 375 R -2) (comment yacute)
   (KRN O 47 R -8) (comment quoteright)
   (KRN C y R -2)
   (KRN C x R -11)
   (KRN C w R -4)
   (KRN C v R -4)
   (KRN C t R 1)
   (STOP)
   (LABEL O 354) (comment igrave)
   (KRN C T R -16)
   (STOP)
   (LABEL O 355) (comment iacute)
   (KRN C T R -16)
   (STOP)
   (LABEL O 356) (comment icircumflex)
   (KRN C T R -16)
   (STOP)
   (LABEL O 357) (comment idieresis)
   (KRN C T R -16)
   (STOP)
   (LABEL O 361) (comment ntilde)
   (KRN O 270 R -14) (comment ydieresis)
   (KRN O 375 R -14) (comment yacute)
   (KRN O 47 R -23) (comment quoteright)
   (KRN C y R -14)
   (KRN C w R -16)
   (KRN C v R -16)
   (KRN C p R 1)
   (KRN C T R -43)
   (STOP)
   (LABEL O 362) (comment ograve)
   (KRN O 270 R -16) (comment ydieresis)
   (KRN O 375 R -16) (comment yacute)
   (KRN O 47 R -14) (comment quoteright)
   (KRN C x R -18)
   (KRN C t R 4)
   (KRN C T R -47)
   (KRN C v R -15)
   (KRN C w R -15)
   (KRN C y R -16)
   (STOP)
   (LABEL O 363) (comment oacute)
   (KRN O 270 R -16) (comment ydieresis)
   (KRN O 375 R -16) (comment yacute)
   (KRN O 47 R -14) (comment quoteright)
   (KRN C x R -18)
   (KRN C t R 4)
   (KRN C T R -47)
   (KRN C v R -15)
   (KRN C w R -15)
   (KRN C y R -16)
   (STOP)
   (LABEL O 364) (comment ocircumflex)
   (KRN O 270 R -16) (comment ydieresis)
   (KRN O 375 R -16) (comment yacute)
   (KRN O 47 R -14) (comment quoteright)
   (KRN C y R -16)
   (KRN C x R -18)
   (KRN C w R -15)
   (KRN C v R -15)
   (KRN C T R -47)
   (KRN C t R 3)
   (STOP)
   (LABEL O 365) (comment otilde)
   (KRN O 270 R -16) (comment ydieresis)
   (KRN O 375 R -16) (comment yacute)
   (KRN O 47 R -14) (comment quoteright)
   (KRN C y R -16)
   (KRN C x R -18)
   (KRN C w R -15)
   (KRN C v R -15)
   (KRN C t R 4)
   (KRN C T R -47)
   (STOP)
   (LABEL O 366) (comment odieresis)
   (KRN O 270 R -16) (comment ydieresis)
   (KRN O 375 R -16) (comment yacute)
   (KRN O 47 R -14) (comment quoteright)
   (KRN C t R 4)
   (KRN C T R -47)
   (KRN C v R -14)
   (KRN C w R -17)
   (KRN C x R -18)
   (KRN C y R -16)
   (STOP)
   (LABEL O 370) (comment oslash)
   (KRN O 270 R -16) (comment ydieresis)
   (KRN O 375 R -16) (comment yacute)
   (KRN O 47 R -14) (comment quoteright)
   (KRN C y R -16)
   (KRN C x R -18)
   (KRN C w R -15)
   (KRN C v R -15)
   (KRN C t R 4)
   (KRN C T R -47)
   (STOP)
   (LABEL O 371) (comment ugrave)
   (KRN O 47 R -24) (comment quoteright)
   (STOP)
   (LABEL O 372) (comment uacute)
   (KRN O 47 R -24) (comment quoteright)
   (STOP)
   (LABEL O 373) (comment ucircumflex)
   (KRN O 47 R -24) (comment quoteright)
   (STOP)
   (LABEL O 374) (comment udieresis)
   (KRN O 47 R -24) (comment quoteright)
   (STOP)
   (LABEL O 375) (comment yacute)
   (KRN O 370 R -8) (comment oslash)
   (KRN O 366 R -6) (comment odieresis)
   (KRN O 363 R -6) (comment oacute)
   (KRN O 362 R -6) (comment ograve)
   (KRN O 352 R -11) (comment ecircumflex)
   (KRN O 351 R -11) (comment eacute)
   (KRN O 350 R -11) (comment egrave)
   (KRN O 346 R -10) (comment ae)
   (KRN O 345 R -4) (comment aring)
   (KRN O 344 R -4) (comment adieresis)
   (KRN O 343 R -4) (comment atilde)
   (KRN O 342 R -4) (comment acircumflex)
   (KRN O 341 R -4) (comment aacute)
   (KRN O 340 R -4) (comment agrave)
   (KRN C s R -7)
   (KRN C o R -6)
   (KRN C l R -8)
   (KRN C g R -11)
   (KRN C e R -11)
   (KRN C c R -7)
   (KRN C a R -4)
   (KRN O 73 R 10) (comment semicolon)
   (KRN O 72 R 5) (comment colon)
   (KRN O 56 R -16) (comment period)
   (KRN O 55 R 4) (comment hyphen)
   (KRN O 54 R -14) (comment comma)
   (KRN O 347 R -7) (comment ccedilla)
   (KRN O 353 R -11) (comment edieresis)
   (KRN O 364 R -6) (comment ocircumflex)
   (KRN O 365 R -6) (comment otilde)
   (KRN O 262 R -7) (comment scaron)
   (STOP)
   )
(CHARACTER O 0 (comment grave)
   (CHARWD R 333)
   (CHARHT R 697)
   )
(CHARACTER O 1 (comment acute)
   (CHARWD R 333)
   (CHARHT R 697)
   (CHARIC R 46)
   )
(CHARACTER O 2 (comment circumflex)
   (CHARWD R 333)
   (CHARHT R 690)
   (CHARIC R 34)
   )
(CHARACTER O 3 (comment tilde)
   (CHARWD R 333)
   (CHARHT R 655)
   (CHARIC R 74)
   )
(CHARACTER O 4 (comment dieresis)
   (CHARWD R 333)
   (CHARHT R 655)
   (CHARIC R 64)
   )
(CHARACTER O 5 (comment hungarumlaut)
   (CHARWD R 333)
   (CHARHT R 697)
   (CHARIC R 165)
   )
(CHARACTER O 6 (comment ring)
   (CHARWD R 333)
   (CHARHT R 754)
   (CHARIC R 7)
   )
(CHARACTER O 7 (comment caron)
   (CHARWD R 333)
   (CHARHT R 690)
   (CHARIC R 78)
   )
(CHARACTER O 10 (comment breve)
   (CHARWD R 333)
   (CHARHT R 678)
   (CHARIC R 54)
   )
(CHARACTER O 11 (comment macron)
   (CHARWD R 333)
   (CHARHT R 623)
   (CHARIC R 60)
   )
(CHARACTER O 12 (comment dotaccent)
   (CHARWD R 333)
   (CHARHT R 655)
   )
(CHARACTER O 13 (comment cedilla)
   (CHARWD R 333)
   (CHARHT R 5)
   (CHARDP R 218)
   )
(CHARACTER O 14 (comment ogonek)
   (CHARWD R 333)
   (CHARHT R 44)
   (CHARDP R 173)
   )
(CHARACTER O 15 (comment quotesinglbase)
   (CHARWD R 333)
   (CHARHT R 134)
   (CHARDP R 182)
   )
(CHARACTER O 16 (comment guilsinglleft)
   (CHARWD R 333)
   (CHARHT R 415)
   )
(CHARACTER O 17 (comment guilsinglright)
   (CHARWD R 333)
   (CHARHT R 415)
   )
(CHARACTER O 20 (comment quotedblleft)
   (CHARWD R 500)
   (CHARHT R 685)
   (CHARIC R 13)
   )
(CHARACTER O 21 (comment quotedblright)
   (CHARWD R 500)
   (CHARHT R 685)
   (CHARIC R 13)
   )
(CHARACTER O 22 (comment quotedblbase)
   (CHARWD R 500)
   (CHARHT R 134)
   (CHARDP R 182)
   )
(CHARACTER O 23 (comment guillemotleft)
   (CHARWD R 500)
   (CHARHT R 415)
   )
(CHARACTER O 24 (comment guillemotright)
   (CHARWD R 500)
   (CHARHT R 415)
   )
(CHARACTER O 25 (comment endash)
   (CHARWD R 500)
   (CHARHT R 269)
   )
(CHARACTER O 26 (comment emdash)
   (CHARWD R 1000)
   (CHARHT R 269)
   )
(CHARACTER O 27 (comment uni200B)
   (CHARWD R 0)
   )
(CHARACTER O 30 (comment perthousandzero)
   (CHARWD R 361)
   (CHARHT R 333)
   (CHARDP R 18)
   )
(CHARACTER O 31 (comment dotlessi)
   (CHARWD R 278)
   (CHARHT R 462)
   (CHARDP R 9)
   )
(CHARACTER O 32 (comment uni0237)
   (CHARWD R 278)
   (CHARHT R 462)
   (CHARDP R 207)
   )
(CHARACTER O 33 (comment ff)
   (CHARWD R 613)
   (CHARHT R 698)
   (CHARDP R 205)
   (CHARIC R 113)
   )
(CHARACTER O 34 (comment fi)
   (CHARWD R 556)
   (CHARHT R 703)
   (CHARDP R 205)
   )
(CHARACTER O 35 (comment fl)
   (CHARWD R 556)
   (CHARHT R 704)
   (CHARDP R 205)
   )
(CHARACTER O 36 (comment ffi)
   (CHARWD R 856)
   (CHARHT R 703)
   (CHARDP R 205)
   )
(CHARACTER O 37 (comment ffl)
   (CHARWD R 854)
   (CHARHT R 704)
   (CHARDP R 205)
   )
(CHARACTER O 40 (comment uni2423)
   (CHARWD R 500)
   (CHARHT R 31)
   (CHARDP R 120)
   )
(CHARACTER O 41 (comment exclam)
   (CHARWD R 389)
   (CHARHT R 684)
   (CHARDP R 13)
   )
(CHARACTER O 42 (comment quotedbl)
   (CHARWD R 555)
   (CHARHT R 685)
   )
(CHARACTER O 43 (comment numbersign)
   (CHARWD R 500)
   (CHARHT R 700)
   (CHARIC R 32)
   )
(CHARACTER O 44 (comment dollar)
   (CHARWD R 500)
   (CHARHT R 733)
   (CHARDP R 100)
   )
(CHARACTER O 45 (comment percent)
   (CHARWD R 757)
   (CHARHT R 706)
   (CHARDP R 29)
   )
(CHARACTER O 46 (comment ampersand)
   (CHARWD R 849)
   (CHARHT R 682)
   (CHARDP R 19)
   )
(CHARACTER O 47 (comment quoteright)
   (CHARWD R 333)
   (CHARHT R 685)
   )
(CHARACTER O 50 (comment parenleft)
   (CHARWD R 333)
   (CHARHT R 685)
   (CHARDP R 179)
   (CHARIC R 11)
   )
(CHARACTER O 51 (comment parenright)
   (CHARWD R 333)
   (CHARHT R 685)
   (CHARDP R 179)
   )
(CHARACTER O 52 (comment asterisk)
   (CHARWD R 500)
   (CHARHT R 685)
   )
(CHARACTER O 53 (comment plus)
   (CHARWD R 570)
   (CHARHT R 506)
   )
(CHARACTER O 54 (comment comma)
   (CHARWD R 250)
   (CHARHT R 134)
   (CHARDP R 182)
   )
(CHARACTER O 55 (comment hyphen)
   (CHARWD R 333)
   (CHARHT R 282)
   )
(CHARACTER O 56 (comment period)
   (CHARWD R 250)
   (CHARHT R 135)
   (CHARDP R 13)
   )
(CHARACTER O 57 (comment slash)
   (CHARWD R 278)
   (CHARHT R 685)
   (CHARDP R 18)
   (CHARIC R 64)
   )
(CHARACTER C 0
   (CHARWD R 500)
   (CHARHT R 683)
   (CHARDP R 14)
   )
(CHARACTER C 1
   (CHARWD R 500)
   (CHARHT R 683)
   )
(CHARACTER C 2
   (CHARWD R 500)
   (CHARHT R 683)
   )
(CHARACTER C 3
   (CHARWD R 500)
   (CHARHT R 683)
   (CHARDP R 13)
   )
(CHARACTER C 4
   (CHARWD R 500)
   (CHARHT R 683)
   (CHARIC R 3)
   )
(CHARACTER C 5
   (CHARWD R 500)
   (CHARHT R 669)
   (CHARDP R 13)
   )
(CHARACTER C 6
   (CHARWD R 500)
   (CHARHT R 679)
   (CHARDP R 15)
   (CHARIC R 9)
   )
(CHARACTER C 7
   (CHARWD R 500)
   (CHARHT R 669)
   (CHARIC R 25)
   )
(CHARACTER C 8
   (CHARWD R 500)
   (CHARHT R 683)
   (CHARDP R 13)
   )
(CHARACTER C 9
   (CHARWD R 500)
   (CHARHT R 683)
   (CHARDP R 10)
   )
(CHARACTER O 72 (comment colon)
   (CHARWD R 333)
   (CHARHT R 459)
   (CHARDP R 13)
   )
(CHARACTER O 73 (comment semicolon)
   (CHARWD R 333)
   (CHARHT R 459)
   (CHARDP R 183)
   )
(CHARACTER O 74 (comment less)
   (CHARWD R 570)
   (CHARHT R 518)
   (CHARDP R 12)
   )
(CHARACTER O 75 (comment equal)
   (CHARWD R 570)
   (CHARHT R 399)
   )
(CHARACTER O 76 (comment greater)
   (CHARWD R 570)
   (CHARHT R 518)
   (CHARDP R 12)
   )
(CHARACTER O 77 (comment question)
   (CHARWD R 500)
   (CHARHT R 684)
   (CHARDP R 13)
   )
(CHARACTER O 100 (comment at)
   (CHARWD R 939)
   (CHARHT R 685)
   (CHARDP R 18)
   )
(CHARACTER C A
   (CHARWD R 667)
   (CHARHT R 683)
   )
(CHARACTER C B
   (CHARWD R 667)
   (CHARHT R 669)
   )
(CHARACTER C C
   (CHARWD R 667)
   (CHARHT R 685)
   (CHARDP R 18)
   (CHARIC R 10)
   )
(CHARACTER C D
   (CHARWD R 722)
   (CHARHT R 669)
   )
(CHARACTER C E
   (CHARWD R 667)
   (CHARHT R 669)
   )
(CHARACTER C F
   (CHARWD R 667)
   (CHARHT R 669)
   )
(CHARACTER C G
   (CHARWD R 722)
   (CHARHT R 685)
   (CHARDP R 18)
   )
(CHARACTER C H
   (CHARWD R 778)
   (CHARHT R 669)
   (CHARIC R 21)
   )
(CHARACTER C I
   (CHARWD R 389)
   (CHARHT R 669)
   (CHARIC R 17)
   )
(CHARACTER C J
   (CHARWD R 500)
   (CHARHT R 669)
   (CHARDP R 99)
   (CHARIC R 24)
   )
(CHARACTER C K
   (CHARWD R 667)
   (CHARHT R 669)
   (CHARIC R 35)
   )
(CHARACTER C L
   (CHARWD R 611)
   (CHARHT R 669)
   )
(CHARACTER C M
   (CHARWD R 889)
   (CHARHT R 669)
   (CHARDP R 12)
   (CHARIC R 28)
   )
(CHARACTER C N
   (CHARWD R 722)
   (CHARHT R 669)
   (CHARDP R 15)
   (CHARIC R 26)
   )
(CHARACTER C O
   (CHARWD R 722)
   (CHARHT R 685)
   (CHARDP R 18)
   )
(CHARACTER C P
   (CHARWD R 611)
   (CHARHT R 669)
   (CHARIC R 2)
   )
(CHARACTER C Q
   (CHARWD R 722)
   (CHARHT R 685)
   (CHARDP R 208)
   )
(CHARACTER C R
   (CHARWD R 667)
   (CHARHT R 669)
   )
(CHARACTER C S
   (CHARWD R 556)
   (CHARHT R 685)
   (CHARDP R 18)
   )
(CHARACTER C T
   (CHARWD R 611)
   (CHARHT R 669)
   (CHARIC R 39)
   )
(CHARACTER C U
   (CHARWD R 722)
   (CHARHT R 669)
   (CHARDP R 18)
   (CHARIC R 22)
   )
(CHARACTER C V
   (CHARWD R 667)
   (CHARHT R 669)
   (CHARDP R 18)
   (CHARIC R 48)
   )
(CHARACTER C W
   (CHARWD R 889)
   (CHARHT R 669)
   (CHARDP R 18)
   (CHARIC R 51)
   )
(CHARACTER C X
   (CHARWD R 667)
   (CHARHT R 669)
   (CHARIC R 27)
   )
(CHARACTER C Y
   (CHARWD R 611)
   (CHARHT R 669)
   (CHARIC R 48)
   )
(CHARACTER C Z
   (CHARWD R 611)
   (CHARHT R 669)
   )
(CHARACTER O 133 (comment bracketleft)
   (CHARWD R 333)
   (CHARHT R 674)
   (CHARDP R 159)
   (CHARIC R 29)
   )
(CHARACTER O 134 (comment backslash)
   (CHARWD R 278)
   (CHARHT R 685)
   (CHARDP R 18)
   (CHARIC R 1)
   )
(CHARACTER O 135 (comment bracketright)
   (CHARWD R 333)
   (CHARHT R 674)
   (CHARDP R 157)
   (CHARIC R 10)
   )
(CHARACTER O 136 (comment asciicircum)
   (CHARWD R 570)
   (CHARHT R 669)
   )
(CHARACTER O 137 (comment underscore)
   (CHARWD R 500)
   (CHARDP R 125)
   )
(CHARACTER O 140 (comment quoteleft)
   (CHARWD R 333)
   (CHARHT R 685)
   )
(CHARACTER C a
   (CHARWD R 500)
   (CHARHT R 462)
   (CHARDP R 14)
   )
(CHARACTER C b
   (CHARWD R 500)
   (CHARHT R 699)
   (CHARDP R 13)
   )
(CHARACTER C c
   (CHARWD R 444)
   (CHARHT R 462)
   (CHARDP R 13)
   )
(CHARACTER C d
   (CHARWD R 500)
   (CHARHT R 699)
   (CHARDP R 13)
   (CHARIC R 17)
   )
(CHARACTER C e
   (CHARWD R 444)
   (CHARHT R 462)
   (CHARDP R 13)
   )
(CHARACTER C f
   (CHARWD R 333)
   (CHARHT R 698)
   (CHARDP R 205)
   (CHARIC R 113)
   )
(CHARACTER C g
   (CHARWD R 500)
   (CHARHT R 462)
   (CHARDP R 203)
   )
(CHARACTER C h
   (CHARWD R 556)
   (CHARHT R 699)
   (CHARDP R 9)
   )
(CHARACTER C i
   (CHARWD R 278)
   (CHARHT R 684)
   (CHARDP R 9)
   )
(CHARACTER C j
   (CHARWD R 278)
   (CHARHT R 685)
   (CHARDP R 207)
   (CHARIC R 1)
   )
(CHARACTER C k
   (CHARWD R 500)
   (CHARHT R 699)
   (CHARDP R 8)
   )
(CHARACTER C l
   (CHARWD R 278)
   (CHARHT R 699)
   (CHARDP R 9)
   (CHARIC R 12)
   )
(CHARACTER C m
   (CHARWD R 778)
   (CHARHT R 462)
   (CHARDP R 9)
   )
(CHARACTER C n
   (CHARWD R 556)
   (CHARHT R 462)
   (CHARDP R 9)
   )
(CHARACTER C o
   (CHARWD R 500)
   (CHARHT R 462)
   (CHARDP R 13)
   )
(CHARACTER C p
   (CHARWD R 500)
   (CHARHT R 462)
   (CHARDP R 205)
   )
(CHARACTER C q
   (CHARWD R 500)
   (CHARHT R 462)
   (CHARDP R 205)
   )
(CHARACTER C r
   (CHARWD R 389)
   (CHARHT R 462)
   )
(CHARACTER C s
   (CHARWD R 389)
   (CHARHT R 462)
   (CHARDP R 13)
   )
(CHARACTER C t
   (CHARWD R 278)
   (CHARHT R 594)
   (CHARDP R 9)
   (CHARIC R 3)
   )
(CHARACTER C u
   (CHARWD R 556)
   (CHARHT R 462)
   (CHARDP R 9)
   )
(CHARACTER C v
   (CHARWD R 444)
   (CHARHT R 462)
   (CHARDP R 13)
   )
(CHARACTER C w
   (CHARWD R 667)
   (CHARHT R 462)
   (CHARDP R 13)
   )
(CHARACTER C x
   (CHARWD R 500)
   (CHARHT R 462)
   (CHARDP R 13)
   )
(CHARACTER C y
   (CHARWD R 444)
   (CHARHT R 462)
   (CHARDP R 205)
   )
(CHARACTER C z
   (CHARWD R 389)
   (CHARHT R 449)
   (CHARDP R 78)
   )
(CHARACTER O 173 (comment braceleft)
   (CHARWD R 348)
   (CHARHT R 686)
   (CHARDP R 187)
   (CHARIC R 88)
   )
(CHARACTER O 174 (comment bar)
   (CHARWD R 220)
   (CHARHT R 685)
   (CHARDP R 18)
   )
(CHARACTER O 175 (comment braceright)
   (CHARWD R 348)
   (CHARHT R 686)
   (CHARDP R 187)
   )
(CHARACTER O 176 (comment asciitilde)
   (CHARWD R 570)
   (CHARHT R 331)
   )
(CHARACTER O 177 (comment uni2010)
   (CHARWD R 333)
   (CHARHT R 282)
   )
(CHARACTER O 200 (comment uni0102)
   (CHARWD R 667)
   (CHARHT R 885)
   )
(CHARACTER O 201 (comment uni0104)
   (CHARWD R 667)
   (CHARHT R 683)
   (CHARDP R 173)
   )
(CHARACTER O 202 (comment uni0106)
   (CHARWD R 667)
   (CHARHT R 904)
   (CHARDP R 18)
   (CHARIC R 10)
   )
(CHARACTER O 203 (comment uni010C)
   (CHARWD R 667)
   (CHARHT R 897)
   (CHARDP R 18)
   (CHARIC R 10)
   )
(CHARACTER O 204 (comment uni010E)
   (CHARWD R 722)
   (CHARHT R 897)
   )
(CHARACTER O 205 (comment uni011A)
   (CHARWD R 667)
   (CHARHT R 897)
   )
(CHARACTER O 206 (comment uni0118)
   (CHARWD R 667)
   (CHARHT R 669)
   (CHARDP R 182)
   )
(CHARACTER O 207 (comment uni011E)
   (CHARWD R 722)
   (CHARHT R 885)
   (CHARDP R 18)
   )
(CHARACTER O 210 (comment uni0139)
   (CHARWD R 611)
   (CHARHT R 904)
   )
(CHARACTER O 211 (comment uni013D)
   (CHARWD R 611)
   (CHARHT R 685)
   (CHARIC R 56)
   )
(CHARACTER O 212 (comment Lslash)
   (CHARWD R 611)
   (CHARHT R 669)
   )
(CHARACTER O 213 (comment uni0143)
   (CHARWD R 722)
   (CHARHT R 904)
   (CHARDP R 15)
   (CHARIC R 26)
   )
(CHARACTER O 214 (comment uni0147)
   (CHARWD R 722)
   (CHARHT R 897)
   (CHARDP R 15)
   (CHARIC R 26)
   )
(CHARACTER O 215 (comment uni014A)
   (CHARWD R 722)
   (CHARHT R 669)
   (CHARDP R 203)
   )
(CHARACTER O 216 (comment uni0150)
   (CHARWD R 722)
   (CHARHT R 904)
   (CHARDP R 18)
   )
(CHARACTER O 217 (comment uni0154)
   (CHARWD R 667)
   (CHARHT R 904)
   )
(CHARACTER O 220 (comment uni0158)
   (CHARWD R 667)
   (CHARHT R 897)
   )
(CHARACTER O 221 (comment uni015A)
   (CHARWD R 556)
   (CHARHT R 904)
   (CHARDP R 18)
   )
(CHARACTER O 222 (comment Scaron)
   (CHARWD R 556)
   (CHARHT R 897)
   (CHARDP R 18)
   )
(CHARACTER O 223 (comment uni015E)
   (CHARWD R 556)
   (CHARHT R 685)
   (CHARDP R 218)
   )
(CHARACTER O 224 (comment uni0164)
   (CHARWD R 611)
   (CHARHT R 897)
   (CHARIC R 39)
   )
(CHARACTER O 225 (comment uni0162)
   (CHARWD R 611)
   (CHARHT R 669)
   (CHARDP R 218)
   (CHARIC R 39)
   )
(CHARACTER O 226 (comment uni0170)
   (CHARWD R 722)
   (CHARHT R 889)
   (CHARDP R 18)
   (CHARIC R 22)
   )
(CHARACTER O 227 (comment uni016E)
   (CHARWD R 722)
   (CHARHT R 921)
   (CHARDP R 18)
   (CHARIC R 22)
   )
(CHARACTER O 230 (comment Ydieresis)
   (CHARWD R 611)
   (CHARHT R 862)
   (CHARIC R 48)
   )
(CHARACTER O 231 (comment uni0179)
   (CHARWD R 611)
   (CHARHT R 904)
   )
(CHARACTER O 232 (comment Zcaron)
   (CHARWD R 611)
   (CHARHT R 897)
   )
(CHARACTER O 233 (comment uni017B)
   (CHARWD R 611)
   (CHARHT R 862)
   )
(CHARACTER O 234 (comment uni0132)
   (CHARWD R 823)
   (CHARHT R 669)
   (CHARDP R 99)
   (CHARIC R 90)
   )
(CHARACTER O 235 (comment uni0130)
   (CHARWD R 389)
   (CHARHT R 862)
   (CHARIC R 17)
   )
(CHARACTER O 236 (comment uni0111)
   (CHARWD R 500)
   (CHARHT R 699)
   (CHARDP R 13)
   (CHARIC R 41)
   )
(CHARACTER O 237 (comment section)
   (CHARWD R 500)
   (CHARHT R 685)
   (CHARDP R 143)
   )
(CHARACTER O 240 (comment uni0103)
   (CHARWD R 500)
   (CHARHT R 678)
   (CHARDP R 14)
   )
(CHARACTER O 241 (comment uni0105)
   (CHARWD R 500)
   (CHARHT R 462)
   (CHARDP R 173)
   (CHARIC R 7)
   )
(CHARACTER O 242 (comment uni0107)
   (CHARWD R 444)
   (CHARHT R 697)
   (CHARDP R 13)
   )
(CHARACTER O 243 (comment uni010D)
   (CHARWD R 444)
   (CHARHT R 690)
   (CHARDP R 13)
   )
(CHARACTER O 244 (comment uni010F)
   (CHARWD R 658)
   (CHARHT R 710)
   (CHARDP R 13)
   (CHARIC R 68)
   )
(CHARACTER O 245 (comment uni011B)
   (CHARWD R 444)
   (CHARHT R 690)
   (CHARDP R 13)
   (CHARIC R 42)
   )
(CHARACTER O 246 (comment uni0119)
   (CHARWD R 444)
   (CHARHT R 462)
   (CHARDP R 182)
   )
(CHARACTER O 247 (comment uni011F)
   (CHARWD R 500)
   (CHARHT R 678)
   (CHARDP R 203)
   )
(CHARACTER O 250 (comment uni013A)
   (CHARWD R 278)
   (CHARHT R 904)
   (CHARDP R 9)
   (CHARIC R 66)
   )
(CHARACTER O 251 (comment uni013E)
   (CHARWD R 451)
   (CHARHT R 710)
   (CHARDP R 9)
   (CHARIC R 48)
   )
(CHARACTER O 252 (comment lslash)
   (CHARWD R 278)
   (CHARHT R 699)
   (CHARDP R 9)
   (CHARIC R 23)
   )
(CHARACTER O 253 (comment uni0144)
   (CHARWD R 556)
   (CHARHT R 697)
   (CHARDP R 9)
   )
(CHARACTER O 254 (comment uni0148)
   (CHARWD R 556)
   (CHARHT R 690)
   (CHARDP R 9)
   )
(CHARACTER O 255 (comment uni014B)
   (CHARWD R 543)
   (CHARHT R 462)
   (CHARDP R 207)
   )
(CHARACTER O 256 (comment uni0151)
   (CHARWD R 500)
   (CHARHT R 697)
   (CHARDP R 13)
   (CHARIC R 19)
   )
(CHARACTER O 257 (comment uni0155)
   (CHARWD R 389)
   (CHARHT R 697)
   )
(CHARACTER O 260 (comment uni0159)
   (CHARWD R 389)
   (CHARHT R 690)
   (CHARIC R 22)
   )
(CHARACTER O 261 (comment uni015B)
   (CHARWD R 389)
   (CHARHT R 697)
   (CHARDP R 13)
   )
(CHARACTER O 262 (comment scaron)
   (CHARWD R 389)
   (CHARHT R 690)
   (CHARDP R 13)
   (CHARIC R 22)
   )
(CHARACTER O 263 (comment uni015F)
   (CHARWD R 389)
   (CHARHT R 462)
   (CHARDP R 218)
   )
(CHARACTER O 264 (comment uni0165)
   (CHARWD R 411)
   (CHARHT R 710)
   (CHARDP R 9)
   (CHARIC R 88)
   )
(CHARACTER O 265 (comment uni0163)
   (CHARWD R 278)
   (CHARHT R 594)
   (CHARDP R 218)
   (CHARIC R 11)
   )
(CHARACTER O 266 (comment uni0171)
   (CHARWD R 556)
   (CHARHT R 697)
   (CHARDP R 9)
   )
(CHARACTER O 267 (comment uni016F)
   (CHARWD R 556)
   (CHARHT R 729)
   (CHARDP R 9)
   )
(CHARACTER O 270 (comment ydieresis)
   (CHARWD R 444)
   (CHARHT R 655)
   (CHARDP R 205)
   (CHARIC R 16)
   )
(CHARACTER O 271 (comment uni017A)
   (CHARWD R 389)
   (CHARHT R 697)
   (CHARDP R 78)
   )
(CHARACTER O 272 (comment zcaron)
   (CHARWD R 389)
   (CHARHT R 690)
   (CHARDP R 78)
   (CHARIC R 22)
   )
(CHARACTER O 273 (comment uni017C)
   (CHARWD R 389)
   (CHARHT R 655)
   (CHARDP R 78)
   )
(CHARACTER O 274 (comment uni0133)
   (CHARWD R 552)
   (CHARHT R 685)
   (CHARDP R 207)
   )
(CHARACTER O 275 (comment exclamdown)
   (CHARWD R 389)
   (CHARHT R 494)
   (CHARDP R 205)
   )
(CHARACTER O 276 (comment questiondown)
   (CHARWD R 500)
   (CHARHT R 492)
   (CHARDP R 205)
   )
(CHARACTER O 277 (comment sterling)
   (CHARWD R 500)
   (CHARHT R 683)
   (CHARDP R 12)
   (CHARIC R 10)
   )
(CHARACTER O 300 (comment Agrave)
   (CHARWD R 667)
   (CHARHT R 947)
   )
(CHARACTER O 301 (comment Aacute)
   (CHARWD R 667)
   (CHARHT R 947)
   )
(CHARACTER O 302 (comment Acircumflex)
   (CHARWD R 667)
   (CHARHT R 940)
   )
(CHARACTER O 303 (comment Atilde)
   (CHARWD R 667)
   (CHARHT R 905)
   )
(CHARACTER O 304 (comment Adieresis)
   (CHARWD R 667)
   (CHARHT R 905)
   )
(CHARACTER O 305 (comment Aring)
   (CHARWD R 667)
   (CHARHT R 1004)
   )
(CHARACTER O 306 (comment AE)
   (CHARWD R 944)
   (CHARHT R 669)
   )
(CHARACTER O 307 (comment Ccedilla)
   (CHARWD R 667)
   (CHARHT R 685)
   (CHARDP R 218)
   (CHARIC R 10)
   )
(CHARACTER O 310 (comment Egrave)
   (CHARWD R 667)
   (CHARHT R 947)
   )
(CHARACTER O 311 (comment Eacute)
   (CHARWD R 667)
   (CHARHT R 947)
   )
(CHARACTER O 312 (comment Ecircumflex)
   (CHARWD R 667)
   (CHARHT R 940)
   )
(CHARACTER O 313 (comment Edieresis)
   (CHARWD R 667)
   (CHARHT R 905)
   )
(CHARACTER O 314 (comment Igrave)
   (CHARWD R 389)
   (CHARHT R 947)
   (CHARIC R 17)
   )
(CHARACTER O 315 (comment Iacute)
   (CHARWD R 389)
   (CHARHT R 947)
   (CHARIC R 51)
   )
(CHARACTER O 316 (comment Icircumflex)
   (CHARWD R 389)
   (CHARHT R 940)
   (CHARIC R 80)
   )
(CHARACTER O 317 (comment Idieresis)
   (CHARWD R 389)
   (CHARHT R 905)
   (CHARIC R 91)
   )
(CHARACTER O 320 (comment Eth)
   (CHARWD R 722)
   (CHARHT R 669)
   )
(CHARACTER O 321 (comment Ntilde)
   (CHARWD R 722)
   (CHARHT R 905)
   (CHARDP R 15)
   (CHARIC R 26)
   )
(CHARACTER O 322 (comment Ograve)
   (CHARWD R 722)
   (CHARHT R 947)
   (CHARDP R 18)
   )
(CHARACTER O 323 (comment Oacute)
   (CHARWD R 722)
   (CHARHT R 947)
   (CHARDP R 18)
   )
(CHARACTER O 324 (comment Ocircumflex)
   (CHARWD R 722)
   (CHARHT R 940)
   (CHARDP R 18)
   )
(CHARACTER O 325 (comment Otilde)
   (CHARWD R 722)
   (CHARHT R 905)
   (CHARDP R 18)
   )
(CHARACTER O 326 (comment Odieresis)
   (CHARWD R 722)
   (CHARHT R 905)
   (CHARDP R 18)
   )
(CHARACTER O 327 (comment OE)
   (CHARWD R 944)
   (CHARHT R 677)
   (CHARDP R 8)
   (CHARIC R 2)
   )
(CHARACTER O 330 (comment Oslash)
   (CHARWD R 722)
   (CHARHT R 764)
   (CHARDP R 125)
   )
(CHARACTER O 331 (comment Ugrave)
   (CHARWD R 722)
   (CHARHT R 947)
   (CHARDP R 18)
   (CHARIC R 22)
   )
(CHARACTER O 332 (comment Uacute)
   (CHARWD R 722)
   (CHARHT R 947)
   (CHARDP R 18)
   (CHARIC R 22)
   )
(CHARACTER O 333 (comment Ucircumflex)
   (CHARWD R 722)
   (CHARHT R 940)
   (CHARDP R 18)
   (CHARIC R 22)
   )
(CHARACTER O 334 (comment Udieresis)
   (CHARWD R 722)
   (CHARHT R 905)
   (CHARDP R 18)
   (CHARIC R 22)
   )
(CHARACTER O 335 (comment Yacute)
   (CHARWD R 611)
   (CHARHT R 947)
   (CHARIC R 48)
   )
(CHARACTER O 336 (comment Thorn)
   (CHARWD R 611)
   (CHARHT R 669)
   )
(CHARACTER O 337 (comment uni1E9E)
   (CHARWD R 1112)
   (CHARHT R 685)
   (CHARDP R 18)
   )
(CHARACTER O 340 (comment agrave)
   (CHARWD R 500)
   (CHARHT R 697)
   (CHARDP R 14)
   )
(CHARACTER O 341 (comment aacute)
   (CHARWD R 500)
   (CHARHT R 697)
   (CHARDP R 14)
   )
(CHARACTER O 342 (comment acircumflex)
   (CHARWD R 500)
   (CHARHT R 690)
   (CHARDP R 14)
   )
(CHARACTER O 343 (comment atilde)
   (CHARWD R 500)
   (CHARHT R 655)
   (CHARDP R 14)
   )
(CHARACTER O 344 (comment adieresis)
   (CHARWD R 500)
   (CHARHT R 655)
   (CHARDP R 14)
   )
(CHARACTER O 345 (comment aring)
   (CHARWD R 500)
   (CHARHT R 756)
   (CHARDP R 14)
   )
(CHARACTER O 346 (comment ae)
   (CHARWD R 722)
   (CHARHT R 462)
   (CHARDP R 13)
   )
(CHARACTER O 347 (comment ccedilla)
   (CHARWD R 444)
   (CHARHT R 462)
   (CHARDP R 218)
   )
(CHARACTER O 350 (comment egrave)
   (CHARWD R 444)
   (CHARHT R 697)
   (CHARDP R 13)
   )
(CHARACTER O 351 (comment eacute)
   (CHARWD R 444)
   (CHARHT R 697)
   (CHARDP R 13)
   )
(CHARACTER O 352 (comment ecircumflex)
   (CHARWD R 444)
   (CHARHT R 690)
   (CHARDP R 13)
   (CHARIC R 18)
   )
(CHARACTER O 353 (comment edieresis)
   (CHARWD R 444)
   (CHARHT R 655)
   (CHARDP R 13)
   (CHARIC R 26)
   )
(CHARACTER O 354 (comment igrave)
   (CHARWD R 278)
   (CHARHT R 697)
   (CHARDP R 9)
   (CHARIC R 16)
   )
(CHARACTER O 355 (comment iacute)
   (CHARWD R 278)
   (CHARHT R 697)
   (CHARDP R 9)
   (CHARIC R 32)
   )
(CHARACTER O 356 (comment icircumflex)
   (CHARWD R 278)
   (CHARHT R 690)
   (CHARDP R 9)
   (CHARIC R 75)
   )
(CHARACTER O 357 (comment idieresis)
   (CHARWD R 278)
   (CHARHT R 655)
   (CHARDP R 9)
   (CHARIC R 84)
   )
(CHARACTER O 360 (comment eth)
   (CHARWD R 500)
   (CHARHT R 699)
   (CHARDP R 13)
   )
(CHARACTER O 361 (comment ntilde)
   (CHARWD R 556)
   (CHARHT R 655)
   (CHARDP R 9)
   )
(CHARACTER O 362 (comment ograve)
   (CHARWD R 500)
   (CHARHT R 697)
   (CHARDP R 13)
   )
(CHARACTER O 363 (comment oacute)
   (CHARWD R 500)
   (CHARHT R 697)
   (CHARDP R 13)
   )
(CHARACTER O 364 (comment ocircumflex)
   (CHARWD R 500)
   (CHARHT R 690)
   (CHARDP R 13)
   )
(CHARACTER O 365 (comment otilde)
   (CHARWD R 500)
   (CHARHT R 655)
   (CHARDP R 13)
   )
(CHARACTER O 366 (comment odieresis)
   (CHARWD R 500)
   (CHARHT R 655)
   (CHARDP R 13)
   )
(CHARACTER O 367 (comment oe)
   (CHARWD R 722)
   (CHARHT R 462)
   (CHARDP R 13)
   )
(CHARACTER O 370 (comment oslash)
   (CHARWD R 500)
   (CHARHT R 560)
   (CHARDP R 119)
   )
(CHARACTER O 371 (comment ugrave)
   (CHARWD R 556)
   (CHARHT R 697)
   (CHARDP R 9)
   )
(CHARACTER O 372 (comment uacute)
   (CHARWD R 556)
   (CHARHT R 697)
   (CHARDP R 9)
   )
(CHARACTER O 373 (comment ucircumflex)
   (CHARWD R 556)
   (CHARHT R 690)
   (CHARDP R 9)
   )
(CHARACTER O 374 (comment udieresis)
   (CHARWD R 556)
   (CHARHT R 655)
   (CHARDP R 9)
   )
(CHARACTER O 375 (comment yacute)
   (CHARWD R 444)
   (CHARHT R 697)
   (CHARDP R 205)
   )
(CHARACTER O 376 (comment thorn)
   (CHARWD R 500)
   (CHARHT R 699)
   (CHARDP R 205)
   )
(CHARACTER O 377 (comment germandbls)
   (CHARWD R 500)
   (CHARHT R 705)
   (CHARDP R 200)
   )
